
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!

      SUBROUTINE HRPRODLOSS

C***********************************************************************
C
C  FUNCTION: To compute the production and loss rates for EBI species
C
C  PRECONDITIONS: For the CB6R3_AE6_AQ mechanism
C
C  RETURN VALUES: None
C
C  KEY SUBROUTINES/FUNCTIONS CALLED: None
C
C  REVISION HISTORY: Created by EBI solver program, Aug  6, 2019
C
C   18 Jul 14 B.Hutzell: revised to use real(8) variables

C***********************************************************************
      USE HRDATA

      IMPLICIT NONE


C.....INCLUDES: NONE


C.....ARGUMENTS: NONE


C.....PARAMETERS: NONE


C.....EXTERNAL FUNCTIONS: NONE


C.....SAVED VARIABLES: NONE
!     CHARACTER( 16 ), SAVE  ::  PNAME = 'HRPRODLOSS'   ! Program name


C.....LOCAL VARIABLES:


C***********************************************************************


      PROD(  H2O2         ) =                 RXRAT(    17 )      ! OH+OH=H2O2
     &                      +                 RXRAT(    19 )      ! HO2+HO2=H2O2
     &                      +                 RXRAT(    20 )      ! HO2+HO2=H2O2
     &                      +    4.0000D-02 * RXRAT(   143 )      ! OLE+O3=0.4000D-01*H2O2+...
     &                      +    8.0000D-02 * RXRAT(   147 )      ! IOLE+O3=0.8000D-01*H2O2+...
      LOSS(  H2O2         ) =                 RXRAT(    21 )      ! H2O2=0.2000D+01*OH
     &                      +                 RXRAT(    22 )      ! H2O2+OH=HO2
     &                      +                 RXRAT(    23 )      ! H2O2+O=OH+HO2

      PROD(  HNO3         ) =    2.0000D+00 * RXRAT(    39 )      ! N2O5=0.2000D+01*HNO3
     &                      +                 RXRAT(    45 )      ! NO2+OH=HNO3
     &                      +                 RXRAT(   100 )      ! FORM+NO3=HNO3+HO2+CO
     &                      +                 RXRAT(   107 )      ! ALD2+NO3=HNO3+C2O3
     &                      +                 RXRAT(   111 )      ! ALDX+NO3=HNO3+CXO3
     &                      +                 RXRAT(   115 )      ! GLYD+NO3=HNO3+C2O3
     &                      +                 RXRAT(   118 )      ! GLY+NO3=HNO3+0.1500D+01*CO+...
     &                      +                 RXRAT(   120 )      ! MGLY+NO3=HNO3+C2O3+XO2+RO2
     &                      +    7.1700D-01 * RXRAT(   160 )      ! ISPD+NO3=0.7170D+00*HNO3+...
     &                      +                 RXRAT(   164 )      ! HPLD+NO3=HNO3+ISPD
     &                      +                 RXRAT(   192 )      ! CRES+NO3=HNO3+0.3000D+...
     &                      +                 RXRAT(   196 )      ! CRON+NO3=HNO3+0.5000D+...
     &                      +                 RXRAT(   205 )      ! OPEN+NO3=HNO3+OPO3
     &                      +                 RXRAT(   207 )      ! CAT1+NO3=HNO3+CRO
     &                      +                 RXRAT(   251 )      ! CLNO3=HNO3+HOCL
     &                      +                 RXRAT(   264 )      ! NTR2=HNO3
     &                      +                 RXRAT(   265 )      ! N2O5=HNO3+H2NO3PIJ
     &                      +                 RXRAT(   266 )      ! N2O5=HNO3+H2NO3PK
     &                      +                 RXRAT(   267 )      ! H2NO3PIJ=HNO3
     &                      +                 RXRAT(   268 )      ! H2NO3PK=HNO3
     &                      +    5.0000D-01 * RXRAT(   272 )      ! NO2=0.5000D+00*HNO3+...
      LOSS(  HNO3         ) =                 RXRAT(    46 )      ! HNO3+OH=NO3
     &                      +                 RXRAT(    47 )      ! HNO3=OH+NO2

      PROD(  SO2          ) =   0.0D0
      LOSS(  SO2          ) =                 RXRAT(    52 )      ! SO2+OH=SULF+HO2+SULRXN

      PROD(  SULF         ) =                 RXRAT(    52 )      ! SO2+OH=SULF+HO2+SULRXN
      LOSS(  SULF         ) =   0.0D0

      PROD(  SULRXN       ) =                 RXRAT(    52 )      ! SO2+OH=SULRXN+HO2+SULF
      LOSS(  SULRXN       ) =   0.0D0

      PROD(  MEO2         ) =                 RXRAT(    53 )      ! C2O3+NO=MEO2+NO2+RO2
     &                      +    4.0000D-01 * RXRAT(    56 )      ! PAN=0.4000D+00*MEO2+...
     &                      +    4.4000D-01 * RXRAT(    57 )      ! C2O3+HO2=0.4400D+00*MEO2+...
     &                      +    2.0000D+00 * RXRAT(    59 )      ! C2O3+C2O3=0.2000D+01*MEO2+...
     &                      +                 RXRAT(    60 )      ! C2O3+CXO3=MEO2+ALD2+XO2H+...
     &                      +    8.0000D-01 * RXRAT(    77 )      ! XO2H+C2O3=0.8000D+00*MEO2+...
     &                      +    8.0000D-01 * RXRAT(    81 )      ! XO2+C2O3=0.8000D+00*MEO2+...
     &                      +    8.0000D-01 * RXRAT(    85 )      ! XO2N+C2O3=0.8000D+00*MEO2+...
     &                      +    6.0000D-01 * RXRAT(    87 )      ! MEPX+OH=0.6000D+00*MEO2+...
     &                      +                 RXRAT(    88 )      ! MEPX=MEO2+RO2+OH
     &                      +                 RXRAT(    94 )      ! AACD+OH=MEO2+RO2
     &                      +                 RXRAT(   108 )      ! ALD2=MEO2+RO2+CO+HO2
     &                      +                 RXRAT(   124 )      ! OH=MEO2+RO2
     &                      +    5.0000D-01 * RXRAT(   128 )      ! KET=0.5000D+00*MEO2+...
     &                      +    1.3800D+00 * RXRAT(   129 )      ! ACET=0.1380D+01*MEO2+...
     &                      +    8.0000D-01 * RXRAT(   153 )      ! ISO2+C2O3=0.8000D+00*MEO2+...
     &                      +    1.1500D-01 * RXRAT(   158 )      ! ISPD+OH=0.1150D+00*MEO2+...
     &                      +    3.4000D-01 * RXRAT(   161 )      ! ISPD=0.3400D+00*MEO2+...
     &                      +    8.0000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.8000D+00*MEO2+...
     &                      +                 RXRAT(   177 )      ! BZO2+C2O3=MEO2+OPEN+HO2+...
     &                      +                 RXRAT(   182 )      ! TO2+C2O3=MEO2+0.5200D+...
     &                      +                 RXRAT(   189 )      ! XLO2+C2O3=MEO2+0.7700D+...
     &                      +                 RXRAT(   212 )      ! OPO3+C2O3=MEO2+XO2+ALDX+...
     &                      +                 RXRAT(   216 )      ! ECH4+OH=MEO2+RO2
     &                      +                 RXRAT(   230 )      ! CL=MEO2+HCL+RO2
      LOSS(  MEO2         ) =                 RXRAT(    71 )      ! MEO2+NO=FORM+HO2+NO2
     &                      +                 RXRAT(    72 )      ! MEO2+HO2=0.9000D+00*MEPX+...
     &                      +    1.0000D-01 * RXRAT(    73 )      ! MEO2+C2O3=0.9000D+00*MEO2+...
     &                      +                 RXRAT(    74 )      ! MEO2+RO2=0.6850D+00*FORM+...
     &                      +                 RXRAT(   227 )      ! MEO2+CLO=CL+FORM+HO2

      PROD(  RO2          ) =                 RXRAT(    53 )      ! C2O3+NO=RO2+MEO2+NO2
     &                      +    4.0000D-01 * RXRAT(    56 )      ! PAN=0.4000D+00*RO2+0.6000D+...
     &                      +    4.4000D-01 * RXRAT(    57 )      ! C2O3+HO2=0.4400D+00*RO2+...
     &                      +    2.0000D+00 * RXRAT(    59 )      ! C2O3+C2O3=0.2000D+01*RO2+...
     &                      +    2.0000D+00 * RXRAT(    60 )      ! C2O3+CXO3=0.2000D+01*RO2+...
     &                      +                 RXRAT(    61 )      ! CXO3+NO=RO2+ALD2+XO2H+NO2
     &                      +    4.0000D-01 * RXRAT(    64 )      ! PANX=0.4000D+00*RO2+...
     &                      +    4.4000D-01 * RXRAT(    65 )      ! CXO3+HO2=0.4400D+00*RO2+...
     &                      +    2.0000D+00 * RXRAT(    67 )      ! CXO3+CXO3=0.2000D+01*RO2+...
     &                      +    9.0000D-01 * RXRAT(    73 )      ! MEO2+C2O3=0.9000D+00*RO2+...
     &                      +    8.0000D-01 * RXRAT(    77 )      ! XO2H+C2O3=0.8000D+00*RO2+...
     &                      +    8.0000D-01 * RXRAT(    81 )      ! XO2+C2O3=0.8000D+00*RO2+...
     &                      +    8.0000D-01 * RXRAT(    85 )      ! XO2N+C2O3=0.8000D+00*RO2+...
     &                      +    6.0000D-01 * RXRAT(    87 )      ! MEPX+OH=0.6000D+00*RO2+...
     &                      +                 RXRAT(    88 )      ! MEPX=RO2+MEO2+OH
     &                      +    6.0000D-01 * RXRAT(    89 )      ! ROOH+OH=0.6000D+00*RO2+...
     &                      +                 RXRAT(    94 )      ! AACD+OH=RO2+MEO2
     &                      +                 RXRAT(   108 )      ! ALD2=RO2+MEO2+CO+HO2
     &                      +                 RXRAT(   112 )      ! ALDX=RO2+XO2H+ALD2+CO+HO2
     &                      +    1.1000D-01 * RXRAT(   114 )      ! GLYD=0.1100D+00*RO2+...
     &                      +    2.0000D-01 * RXRAT(   116 )      ! GLY+OH=0.2000D+00*RO2+...
     &                      +    5.0000D-01 * RXRAT(   118 )      ! GLY+NO3=0.5000D+00*RO2+...
     &                      +                 RXRAT(   120 )      ! MGLY+NO3=RO2+C2O3+XO2+HNO3
     &                      +                 RXRAT(   124 )      ! OH=RO2+MEO2
     &                      +                 RXRAT(   125 )      ! ETHA+OH=RO2+0.9910D+...
     &                      +    1.0000D-01 * RXRAT(   127 )      ! ETOH+OH=0.1000D+00*RO2+...
     &                      +                 RXRAT(   128 )      ! KET=RO2+0.5000D+00*C2O3+...
     &                      +    1.3800D+00 * RXRAT(   129 )      ! ACET=0.1380D+01*RO2+...
     &                      +                 RXRAT(   130 )      ! ACET+OH=RO2+C2O3+XO2+FORM
     &                      +    9.8000D-01 * RXRAT(   133 )      ! ROR=0.9800D+00*RO2+0.4200D+...
     &                      +    7.0000D-01 * RXRAT(   137 )      ! ETH+O=0.7000D+00*RO2+HO2+...
     &                      +                 RXRAT(   138 )      ! ETH+OH=RO2+XO2H+0.1560D+...
     &                      +                 RXRAT(   140 )      ! ETH+NO3=RO2+0.5000D+...
     &                      +    2.1000D-01 * RXRAT(   141 )      ! OLE+O=0.2100D+00*RO2+...
     &                      +    1.1950D+00 * RXRAT(   142 )      ! OLE+OH=0.1195D+01*RO2+...
     &                      +    1.5000D-01 * RXRAT(   143 )      ! OLE+O3=0.1500D+00*RO2+...
     &                      +                 RXRAT(   144 )      ! OLE+NO3=RO2+0.5000D+...
     &                      +    1.0000D-01 * RXRAT(   145 )      ! IOLE+O=0.1000D+00*RO2+...
     &                      +                 RXRAT(   146 )      ! IOLE+OH=RO2+0.7000D+...
     &                      +    3.0000D-01 * RXRAT(   147 )      ! IOLE+O3=0.3000D+00*RO2+...
     &                      +                 RXRAT(   148 )      ! IOLE+NO3=RO2+0.5000D+...
     &                      +                 RXRAT(   149 )      ! ISOP+OH=RO2+ISO2+ISOPRXN
     &                      +    2.5000D-01 * RXRAT(   150 )      ! ISOP+O=0.2500D+00*RO2+...
     &                      +    8.2000D-02 * RXRAT(   151 )      ! ISO2+NO=0.8200D-01*RO2+...
     &                      +    8.7200D-01 * RXRAT(   153 )      ! ISO2+C2O3=0.8720D+00*RO2+...
     &                      +    7.2000D-02 * RXRAT(   154 )      ! ISO2+RO2=0.1072D+01*RO2+...
     &                      +    2.0000D-01 * RXRAT(   156 )      ! ISOP+O3=0.2000D+00*RO2+...
     &                      +                 RXRAT(   157 )      ! ISOP+NO3=RO2+0.6500D+...
     &                      +    6.5800D-01 * RXRAT(   158 )      ! ISPD+OH=0.6580D+00*RO2+...
     &                      +    2.8400D-01 * RXRAT(   160 )      ! ISPD+NO3=0.2840D+00*RO2+...
     &                      +    8.4000D-01 * RXRAT(   161 )      ! ISPD=0.8400D+00*RO2+...
     &                      +    6.7000D-02 * RXRAT(   162 )      ! ISPX+OH=0.6700D-01*RO2+...
     &                      +                 RXRAT(   165 )      ! EPOX+OH=RO2+EPX2
     &                      +    8.0000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.8000D+00*RO2+...
     &                      +                 RXRAT(   170 )      ! INTR+OH=RO2+0.3700D+...
     &                      +    1.5000D+00 * RXRAT(   172 )      ! TERP+OH=0.1500D+01*RO2+...
     &                      +    9.4000D-01 * RXRAT(   173 )      ! TERP+O3=0.9400D+00*RO2+...
     &                      +    1.2800D+00 * RXRAT(   174 )      ! TERP+NO3=0.1280D+01*RO2+...
     &                      +    3.5200D-01 * RXRAT(   175 )      ! BENZENE+OH=0.3520D+00*RO2+...
     &                      +                 RXRAT(   177 )      ! BZO2+C2O3=RO2+OPEN+HO2+...
     &                      +    7.2000D-01 * RXRAT(   180 )      ! TOL+OH=0.7200D+00*RO2+...
     &                      +                 RXRAT(   182 )      ! TO2+C2O3=RO2+0.5200D+...
     &                      +    6.0200D-01 * RXRAT(   185 )      ! XYLMN+OH=0.6020D+00*RO2+...
     &                      +    6.0200D-01 * RXRAT(   186 )      ! NAPH+OH=0.6020D+00*RO2+...
     &                      +                 RXRAT(   189 )      ! XLO2+C2O3=RO2+0.7700D+...
     &                      +    2.0000D-02 * RXRAT(   191 )      ! CRES+OH=0.2000D-01*RO2+...
     &                      +    7.0000D-01 * RXRAT(   192 )      ! CRES+NO3=0.7000D+00*RO2+...
     &                      +    2.0000D+00 * RXRAT(   199 )      ! XOPN+OH=0.2000D+01*RO2+...
     &                      +    3.0000D-01 * RXRAT(   200 )      ! XOPN+O3=0.3000D+00*RO2+...
     &                      +                 RXRAT(   201 )      ! XOPN+NO3=RO2+0.5000D+...
     &                      +    4.0000D-01 * RXRAT(   203 )      ! OPEN+OH=0.4000D+00*RO2+...
     &                      +    4.4000D-01 * RXRAT(   211 )      ! OPO3+HO2=0.4400D+00*RO2+...
     &                      +    2.0000D+00 * RXRAT(   212 )      ! OPO3+C2O3=0.2000D+01*RO2+...
     &                      +    8.0000D-01 * RXRAT(   213 )      ! OPO3+RO2=0.1800D+01*RO2+...
     &                      +                 RXRAT(   216 )      ! ECH4+OH=RO2+MEO2
     &                      +                 RXRAT(   217 )      ! XPRP=RO2+XO2N
     &                      +                 RXRAT(   218 )      ! XPRP=RO2+0.2680D+00*ALDX+...
     &                      +                 RXRAT(   219 )      ! XPAR=RO2+XO2N
     &                      +                 RXRAT(   220 )      ! XPAR=RO2+0.8740D+00*ROR+...
     &                      +                 RXRAT(   230 )      ! CL=RO2+MEO2+HCL
     &                      +                 RXRAT(   232 )      ! CL+PRPA=RO2+ACET+0.9700D+...
     &                      +                 RXRAT(   233 )      ! CL+ETHA=RO2+0.9910D+...
     &                      +                 RXRAT(   237 )      ! CL+ISOP=RO2+ISPD+0.9600D+...
     &                      +    7.2000D-01 * RXRAT(   244 )      ! CL+TOL=0.7200D+00*RO2+...
     &                      +    6.0200D-01 * RXRAT(   245 )      ! CL+XYLMN=0.6020D+00*RO2+...
     &                      +    6.0200D-01 * RXRAT(   246 )      ! CL+NAPH=0.6020D+00*RO2+...
      LOSS(  RO2          ) =                 RXRAT(    58 )      ! RO2+C2O3=C2O3
     &                      +    2.0000D-01 * RXRAT(    66 )      ! RO2+CXO3=0.8000D+00*RO2+...
     &                      +                 RXRAT(    68 )      ! RO2+NO=NO
     &                      +                 RXRAT(    69 )      ! RO2+HO2=HO2
     &                      +    2.0000D+00 * RXRAT(    70 )      ! RO2+RO2=

      PROD(  PACD         ) =    4.1000D-01 * RXRAT(    57 )      ! C2O3+HO2=0.4100D+00*PACD+...
     &                      +    4.1000D-01 * RXRAT(    65 )      ! CXO3+HO2=0.4100D+00*PACD+...
     &                      +    4.1000D-01 * RXRAT(   211 )      ! OPO3+HO2=0.4100D+00*PACD+...
      LOSS(  PACD         ) =                 RXRAT(    95 )      ! PACD+OH=C2O3

      PROD(  AACD         ) =    1.5000D-01 * RXRAT(    57 )      ! C2O3+HO2=0.1500D+00*AACD+...
     &                      +    1.5000D-01 * RXRAT(    65 )      ! CXO3+HO2=0.1500D+00*AACD+...
     &                      +    1.0000D-01 * RXRAT(    73 )      ! MEO2+C2O3=0.1000D+00*AACD+...
     &                      +    2.0000D-01 * RXRAT(    77 )      ! XO2H+C2O3=0.2000D+00*AACD+...
     &                      +    2.0000D-01 * RXRAT(    81 )      ! XO2+C2O3=0.2000D+00*AACD+...
     &                      +    2.0000D-01 * RXRAT(    85 )      ! XO2N+C2O3=0.2000D+00*AACD+...
     &                      +    1.3000D-01 * RXRAT(   143 )      ! OLE+O3=0.1300D+00*AACD+...
     &                      +    8.0000D-02 * RXRAT(   147 )      ! IOLE+O3=0.8000D-01*AACD+...
     &                      +    2.0000D-01 * RXRAT(   153 )      ! ISO2+C2O3=0.2000D+00*AACD+...
     &                      +    2.0000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.2000D+00*AACD+...
     &                      +    1.5000D-01 * RXRAT(   211 )      ! OPO3+HO2=0.1500D+00*AACD+...
     &                      +    2.0000D-01 * RXRAT(   213 )      ! OPO3+RO2=0.2000D+00*AACD+...
      LOSS(  AACD         ) =                 RXRAT(    94 )      ! AACD+OH=MEO2+RO2

      PROD(  CXO3         ) =                 RXRAT(    63 )      ! PANX=CXO3+NO2
     &                      +    6.0000D-01 * RXRAT(    64 )      ! PANX=0.6000D+00*CXO3+...
     &                      +                 RXRAT(   109 )      ! ALDX+O=CXO3+OH
     &                      +                 RXRAT(   110 )      ! ALDX+OH=CXO3
     &                      +                 RXRAT(   111 )      ! ALDX+NO3=CXO3+HNO3
     &                      +    5.0000D-01 * RXRAT(   128 )      ! KET=0.5000D+00*CXO3+...
     &                      +    2.5000D-01 * RXRAT(   150 )      ! ISOP+O=0.2500D+00*CXO3+...
     &                      +    2.0000D-01 * RXRAT(   156 )      ! ISOP+O3=0.2000D+00*CXO3+...
     &                      +    7.1700D-01 * RXRAT(   160 )      ! ISPD+NO3=0.7170D+00*CXO3+...
     &                      +    3.9000D-01 * RXRAT(   173 )      ! TERP+O3=0.3900D+00*CXO3+...
     &                      +    2.0000D-01 * RXRAT(   208 )      ! OPO3+NO=0.2000D+00*CXO3+...
     &                      +                 RXRAT(   240 )      ! CL+ALDX=CXO3+HCL
      LOSS(  CXO3         ) =                 RXRAT(    60 )      ! CXO3+C2O3=MEO2+ALD2+XO2H+...
     &                      +                 RXRAT(    61 )      ! CXO3+NO=NO2+ALD2+XO2H+RO2
     &                      +                 RXRAT(    62 )      ! CXO3+NO2=PANX
     &                      +                 RXRAT(    65 )      ! CXO3+HO2=0.4100D+00*PACD+...
     &                      +                 RXRAT(    66 )      ! CXO3+RO2=0.8000D+00*ALD2+...
     &                      +    2.0000D+00 * RXRAT(    67 )      ! CXO3+CXO3=0.2000D+01*ALD2+...

      PROD(  ALD2         ) =                 RXRAT(    60 )      ! C2O3+CXO3=ALD2+MEO2+XO2H+...
     &                      +                 RXRAT(    61 )      ! CXO3+NO=ALD2+NO2+XO2H+RO2
     &                      +    4.0000D-01 * RXRAT(    64 )      ! PANX=0.4000D+00*ALD2+...
     &                      +    4.4000D-01 * RXRAT(    65 )      ! CXO3+HO2=0.4400D+00*ALD2+...
     &                      +    8.0000D-01 * RXRAT(    66 )      ! CXO3+RO2=0.8000D+00*ALD2+...
     &                      +    2.0000D+00 * RXRAT(    67 )      ! CXO3+CXO3=0.2000D+01*ALD2+...
     &                      +                 RXRAT(   112 )      ! ALDX=ALD2+XO2H+RO2+CO+HO2
     &                      +    9.9100D-01 * RXRAT(   125 )      ! ETHA+OH=0.9910D+00*ALD2+...
     &                      +    9.5000D-01 * RXRAT(   127 )      ! ETOH+OH=0.9500D+00*ALD2+...
     &                      +    5.0000D-01 * RXRAT(   128 )      ! KET=0.5000D+00*ALD2+...
     &                      +    7.4000D-01 * RXRAT(   133 )      ! ROR=0.7400D+00*ALD2+...
     &                      +    2.0000D-01 * RXRAT(   141 )      ! OLE+O=0.2000D+00*ALD2+...
     &                      +    4.8800D-01 * RXRAT(   142 )      ! OLE+OH=0.4880D+00*ALD2+...
     &                      +    2.9500D-01 * RXRAT(   143 )      ! OLE+O3=0.2950D+00*ALD2+...
     &                      +    2.5000D-01 * RXRAT(   144 )      ! OLE+NO3=0.2500D+00*ALD2+...
     &                      +    1.2400D+00 * RXRAT(   145 )      ! IOLE+O=0.1240D+01*ALD2+...
     &                      +    1.3000D+00 * RXRAT(   146 )      ! IOLE+OH=0.1300D+01*ALD2+...
     &                      +    7.3200D-01 * RXRAT(   147 )      ! IOLE+O3=0.7320D+00*ALD2+...
     &                      +    5.0000D-01 * RXRAT(   148 )      ! IOLE+NO3=0.5000D+00*ALD2+...
     &                      +    4.0000D-02 * RXRAT(   159 )      ! ISPD+O3=0.4000D-01*ALD2+...
     &                      +    1.0000D-01 * RXRAT(   200 )      ! XOPN+O3=0.1000D+00*ALD2+...
     &                      +    2.0000D-02 * RXRAT(   204 )      ! OPEN+O3=0.2000D-01*ALD2+...
     &                      +                 RXRAT(   215 )      ! PANX+OH=ALD2+NO2
     &                      +    9.9100D-01 * RXRAT(   233 )      ! CL+ETHA=0.9910D+00*ALD2+...
     &                      +    3.3000D-01 * RXRAT(   235 )      ! CL+OLE=0.3300D+00*ALD2+...
     &                      +    4.5000D-01 * RXRAT(   236 )      ! CL+IOLE=0.4500D+00*ALD2+...
     &                      +                 RXRAT(   242 )      ! CL+ETOH=ALD2+HO2+HCL
      LOSS(  ALD2         ) =                 RXRAT(   105 )      ! ALD2+O=C2O3+OH
     &                      +                 RXRAT(   106 )      ! ALD2+OH=C2O3
     &                      +                 RXRAT(   107 )      ! ALD2+NO3=C2O3+HNO3
     &                      +                 RXRAT(   108 )      ! ALD2=MEO2+RO2+CO+HO2
     &                      +                 RXRAT(   239 )      ! ALD2+CL=HCL+C2O3

      PROD(  XO2H         ) =                 RXRAT(    60 )      ! C2O3+CXO3=XO2H+ALD2+MEO2+...
     &                      +                 RXRAT(    61 )      ! CXO3+NO=XO2H+ALD2+NO2+RO2
     &                      +    4.0000D-01 * RXRAT(    64 )      ! PANX=0.4000D+00*XO2H+...
     &                      +    4.4000D-01 * RXRAT(    65 )      ! CXO3+HO2=0.4400D+00*XO2H+...
     &                      +    8.0000D-01 * RXRAT(    66 )      ! CXO3+RO2=0.8000D+00*XO2H+...
     &                      +    2.0000D+00 * RXRAT(    67 )      ! CXO3+CXO3=0.2000D+01*XO2H+...
     &                      +    5.4000D-01 * RXRAT(    89 )      ! ROOH+OH=0.5400D+00*XO2H+...
     &                      +                 RXRAT(   112 )      ! ALDX=XO2H+ALD2+RO2+CO+HO2
     &                      +    1.1000D-01 * RXRAT(   114 )      ! GLYD=0.1100D+00*XO2H+...
     &                      +    9.9100D-01 * RXRAT(   125 )      ! ETHA+OH=0.9910D+00*XO2H+...
     &                      +    1.0000D-01 * RXRAT(   127 )      ! ETOH+OH=0.1000D+00*XO2H+...
     &                      +    5.0000D-01 * RXRAT(   128 )      ! KET=0.5000D+00*XO2H+...
     &                      +    9.4000D-01 * RXRAT(   133 )      ! ROR=0.9400D+00*XO2H+...
     &                      +    7.0000D-01 * RXRAT(   137 )      ! ETH+O=0.7000D+00*XO2H+HO2+...
     &                      +                 RXRAT(   138 )      ! ETH+OH=XO2H+RO2+0.1560D+...
     &                      +    5.0000D-01 * RXRAT(   140 )      ! ETH+NO3=0.5000D+00*XO2H+...
     &                      +    2.0000D-01 * RXRAT(   141 )      ! OLE+O=0.2000D+00*XO2H+...
     &                      +    9.7600D-01 * RXRAT(   142 )      ! OLE+OH=0.9760D+00*XO2H+...
     &                      +    1.5000D-01 * RXRAT(   143 )      ! OLE+O3=0.1500D+00*XO2H+...
     &                      +    4.8000D-01 * RXRAT(   144 )      ! OLE+NO3=0.4800D+00*XO2H+...
     &                      +    1.0000D-01 * RXRAT(   145 )      ! IOLE+O=0.1000D+00*XO2H+...
     &                      +                 RXRAT(   146 )      ! IOLE+OH=XO2H+0.7000D+...
     &                      +    3.0000D-01 * RXRAT(   147 )      ! IOLE+O3=0.3000D+00*XO2H+...
     &                      +    4.8000D-01 * RXRAT(   148 )      ! IOLE+NO3=0.4800D+00*XO2H+...
     &                      +    8.2000D-02 * RXRAT(   151 )      ! ISO2+NO=0.8200D-01*XO2H+...
     &                      +    7.2000D-02 * RXRAT(   153 )      ! ISO2+C2O3=0.7200D-01*XO2H+...
     &                      +    7.2000D-02 * RXRAT(   154 )      ! ISO2+RO2=0.7200D-01*XO2H+...
     &                      +    6.4000D-01 * RXRAT(   157 )      ! ISOP+NO3=0.6400D+00*XO2H+...
     &                      +    1.4200D-01 * RXRAT(   160 )      ! ISPD+NO3=0.1420D+00*XO2H+...
     &                      +    3.4000D-01 * RXRAT(   161 )      ! ISPD=0.3400D+00*XO2H+...
     &                      +    3.7000D-01 * RXRAT(   170 )      ! INTR+OH=0.3700D+00*XO2H+...
     &                      +    7.5000D-01 * RXRAT(   172 )      ! TERP+OH=0.7500D+00*XO2H+...
     &                      +    7.0000D-02 * RXRAT(   173 )      ! TERP+O3=0.7000D-01*XO2H+...
     &                      +    2.8000D-01 * RXRAT(   174 )      ! TERP+NO3=0.2800D+00*XO2H+...
     &                      +    7.0000D-02 * RXRAT(   180 )      ! TOL+OH=0.7000D-01*XO2H+...
     &                      +    5.8000D-02 * RXRAT(   185 )      ! XYLMN+OH=0.5800D-01*XO2H+...
     &                      +    5.8000D-02 * RXRAT(   186 )      ! NAPH+OH=0.5800D-01*XO2H+...
     &                      +    1.2000D-01 * RXRAT(   192 )      ! CRES+NO3=0.1200D+00*XO2H+...
     &                      +                 RXRAT(   198 )      ! XOPN=XO2H+0.4000D+00*GLY+...
     &                      +    2.0000D+00 * RXRAT(   199 )      ! XOPN+OH=0.2000D+01*XO2H+...
     &                      +    3.0000D-01 * RXRAT(   200 )      ! XOPN+O3=0.3000D+00*XO2H+...
     &                      +    4.5000D-01 * RXRAT(   201 )      ! XOPN+NO3=0.4500D+00*XO2H+...
     &                      +    4.0000D-01 * RXRAT(   203 )      ! OPEN+OH=0.4000D+00*XO2H+...
     &                      +    4.4000D-01 * RXRAT(   211 )      ! OPO3+HO2=0.4400D+00*XO2H+...
     &                      +    8.0000D-01 * RXRAT(   213 )      ! OPO3+RO2=0.8000D+00*XO2H+...
     &                      +                 RXRAT(   218 )      ! XPRP=XO2H+0.2680D+00*ALDX+...
     &                      +    1.2600D-01 * RXRAT(   220 )      ! XPAR=0.1260D+00*XO2H+...
     &                      +    9.7000D-01 * RXRAT(   232 )      ! CL+PRPA=0.9700D+00*XO2H+...
     &                      +    9.9100D-01 * RXRAT(   233 )      ! CL+ETHA=0.9910D+00*XO2H+...
     &                      +    9.6000D-01 * RXRAT(   237 )      ! CL+ISOP=0.9600D+00*XO2H+...
     &                      +    7.0000D-02 * RXRAT(   244 )      ! CL+TOL=0.7000D-01*XO2H+...
     &                      +    5.8000D-02 * RXRAT(   245 )      ! CL+XYLMN=0.5800D-01*XO2H+...
     &                      +    5.8000D-02 * RXRAT(   246 )      ! CL+NAPH=0.5800D-01*XO2H+...
      LOSS(  XO2H         ) =                 RXRAT(    75 )      ! XO2H+NO=NO2+HO2
     &                      +                 RXRAT(    76 )      ! XO2H+HO2=ROOH
     &                      +                 RXRAT(    77 )      ! XO2H+C2O3=0.8000D+00*HO2+...
     &                      +                 RXRAT(    78 )      ! XO2H+RO2=0.6000D+00*HO2+RO2

      PROD(  PANX         ) =                 RXRAT(    62 )      ! CXO3+NO2=PANX
      LOSS(  PANX         ) =                 RXRAT(    63 )      ! PANX=NO2+CXO3
     &                      +                 RXRAT(    64 )      ! PANX=0.6000D+00*NO2+...
     &                      +                 RXRAT(   215 )      ! PANX+OH=ALD2+NO2

      PROD(  FORM         ) =                 RXRAT(    71 )      ! MEO2+NO=FORM+HO2+NO2
     &                      +    1.0000D-01 * RXRAT(    72 )      ! MEO2+HO2=0.1000D+00*FORM+...
     &                      +                 RXRAT(    73 )      ! MEO2+C2O3=FORM+0.9000D+...
     &                      +    6.8500D-01 * RXRAT(    74 )      ! MEO2+RO2=0.6850D+00*FORM+...
     &                      +    4.0000D-01 * RXRAT(    87 )      ! MEPX+OH=0.4000D+00*FORM+...
     &                      +                 RXRAT(   102 )      ! HCO3=FORM+HO2
     &                      +    7.4000D-01 * RXRAT(   114 )      ! GLYD=0.7400D+00*FORM+...
     &                      +                 RXRAT(   126 )      ! MEOH+OH=FORM+HO2
     &                      +    7.8000D-02 * RXRAT(   127 )      ! ETOH+OH=0.7800D-01*FORM+...
     &                      +                 RXRAT(   130 )      ! ACET+OH=FORM+C2O3+XO2+RO2
     &                      +                 RXRAT(   137 )      ! ETH+O=FORM+HO2+CO+0.7000D+...
     &                      +    1.5600D+00 * RXRAT(   138 )      ! ETH+OH=0.1560D+01*FORM+RO2+...
     &                      +                 RXRAT(   139 )      ! ETH+O3=FORM+0.5100D+00*CO+...
     &                      +    1.1250D+00 * RXRAT(   140 )      ! ETH+NO3=0.1125D+01*FORM+...
     &                      +    2.0000D-01 * RXRAT(   141 )      ! OLE+O=0.2000D+00*FORM+...
     &                      +    7.8100D-01 * RXRAT(   142 )      ! OLE+OH=0.7810D+00*FORM+...
     &                      +    5.5500D-01 * RXRAT(   143 )      ! OLE+O3=0.5550D+00*FORM+...
     &                      +    5.0000D-01 * RXRAT(   144 )      ! OLE+NO3=0.5000D+00*FORM+...
     &                      +    1.2800D-01 * RXRAT(   147 )      ! IOLE+O3=0.1280D+00*FORM+...
     &                      +    5.0000D-01 * RXRAT(   150 )      ! ISOP+O=0.5000D+00*FORM+...
     &                      +    6.7300D-01 * RXRAT(   151 )      ! ISO2+NO=0.6730D+00*FORM+...
     &                      +    1.2000D-01 * RXRAT(   152 )      ! ISO2+HO2=0.1200D+00*FORM+...
     &                      +    5.9800D-01 * RXRAT(   153 )      ! ISO2+C2O3=0.5980D+00*FORM+...
     &                      +    5.9800D-01 * RXRAT(   154 )      ! ISO2+RO2=0.5980D+00*FORM+...
     &                      +    6.0000D-01 * RXRAT(   156 )      ! ISOP+O3=0.6000D+00*FORM+...
     &                      +    3.5000D-01 * RXRAT(   157 )      ! ISOP+NO3=0.3500D+00*FORM+...
     &                      +    2.3100D-01 * RXRAT(   159 )      ! ISPD+O3=0.2310D+00*FORM+...
     &                      +    2.6000D-01 * RXRAT(   161 )      ! ISPD=0.2600D+00*FORM+...
     &                      +    3.7500D-01 * RXRAT(   166 )      ! EPX2+HO2=0.3750D+00*FORM+...
     &                      +    3.7500D-01 * RXRAT(   167 )      ! EPX2+NO=0.3750D+00*FORM+...
     &                      +    3.0000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.3000D+00*FORM+...
     &                      +    3.7500D-01 * RXRAT(   169 )      ! EPX2+RO2=0.3750D+00*FORM+...
     &                      +    5.9200D-01 * RXRAT(   170 )      ! INTR+OH=0.5920D+00*FORM+...
     &                      +    2.8000D-01 * RXRAT(   172 )      ! TERP+OH=0.2800D+00*FORM+...
     &                      +    2.4000D-01 * RXRAT(   173 )      ! TERP+O3=0.2400D+00*FORM+...
     &                      +                 RXRAT(   197 )      ! CRON=FORM+HO2+HONO+OPEN
     &                      +    8.0000D-02 * RXRAT(   204 )      ! OPEN+O3=0.8000D-01*FORM+...
     &                      +    1.4000D-01 * RXRAT(   206 )      ! CAT1+OH=0.1400D+00*FORM+...
     &                      +                 RXRAT(   227 )      ! CLO+MEO2=FORM+CL+HO2
     &                      +                 RXRAT(   234 )      ! CL+ETH=FORM+0.2000D+01*XO2+...
     &                      +                 RXRAT(   241 )      ! CL+MEOH=FORM+HO2+HCL
      LOSS(  FORM         ) =                 RXRAT(    96 )      ! FORM+OH=HO2+CO
     &                      +                 RXRAT(    97 )      ! FORM=0.2000D+01*HO2+CO
     &                      +                 RXRAT(    98 )      ! FORM=CO
     &                      +                 RXRAT(    99 )      ! FORM+O=OH+HO2+CO
     &                      +                 RXRAT(   100 )      ! FORM+NO3=HNO3+HO2+CO
     &                      +                 RXRAT(   101 )      ! FORM+HO2=HCO3
     &                      +                 RXRAT(   238 )      ! FORM+CL=HCL+HO2+CO

      PROD(  MEPX         ) =    9.0000D-01 * RXRAT(    72 )      ! MEO2+HO2=0.9000D+00*MEPX+...
     &                      +    5.0000D-01 * RXRAT(   104 )      ! HCO3+HO2=0.5000D+00*MEPX+...
      LOSS(  MEPX         ) =                 RXRAT(    87 )      ! MEPX+OH=0.6000D+00*MEO2+...
     &                      +                 RXRAT(    88 )      ! MEPX=MEO2+RO2+OH

      PROD(  MEOH         ) =    3.1500D-01 * RXRAT(    74 )      ! MEO2+RO2=0.3150D+00*MEOH+...
     &                      +    1.5000D-01 * RXRAT(   114 )      ! GLYD=0.1500D+00*MEOH+...
      LOSS(  MEOH         ) =                 RXRAT(   126 )      ! MEOH+OH=FORM+HO2
     &                      +                 RXRAT(   241 )      ! MEOH+CL=HCL+HO2+FORM

      PROD(  ROOH         ) =                 RXRAT(    76 )      ! XO2H+HO2=ROOH
     &                      +                 RXRAT(    80 )      ! XO2+HO2=ROOH
     &                      +                 RXRAT(    84 )      ! XO2N+HO2=ROOH
      LOSS(  ROOH         ) =                 RXRAT(    89 )      ! ROOH+OH=0.5400D+00*XO2H+...
     &                      +                 RXRAT(    90 )      ! ROOH=HO2+OH

      PROD(  XO2          ) =    2.0000D-01 * RXRAT(   116 )      ! GLY+OH=0.2000D+00*XO2+...
     &                      +    5.0000D-01 * RXRAT(   118 )      ! GLY+NO3=0.5000D+00*XO2+...
     &                      +                 RXRAT(   120 )      ! MGLY+NO3=XO2+C2O3+HNO3+RO2
     &                      +                 RXRAT(   130 )      ! ACET+OH=XO2+C2O3+FORM+RO2
     &                      +    5.0000D-01 * RXRAT(   140 )      ! ETH+NO3=0.5000D+00*XO2+...
     &                      +    1.9500D-01 * RXRAT(   142 )      ! OLE+OH=0.1950D+00*XO2+...
     &                      +    4.8000D-01 * RXRAT(   144 )      ! OLE+NO3=0.4800D+00*XO2+...
     &                      +    4.8000D-01 * RXRAT(   148 )      ! IOLE+NO3=0.4800D+00*XO2+...
     &                      +    2.5000D-01 * RXRAT(   150 )      ! ISOP+O=0.2500D+00*XO2+...
     &                      +    2.0000D-01 * RXRAT(   156 )      ! ISOP+O3=0.2000D+00*XO2+...
     &                      +    3.3000D-01 * RXRAT(   157 )      ! ISOP+NO3=0.3300D+00*XO2+...
     &                      +    5.2100D-01 * RXRAT(   158 )      ! ISPD+OH=0.5210D+00*XO2+...
     &                      +    1.4200D-01 * RXRAT(   160 )      ! ISPD+NO3=0.1420D+00*XO2+...
     &                      +    1.6000D-01 * RXRAT(   161 )      ! ISPD=0.1600D+00*XO2+...
     &                      +    6.3000D-01 * RXRAT(   170 )      ! INTR+OH=0.6300D+00*XO2+...
     &                      +    5.0000D-01 * RXRAT(   172 )      ! TERP+OH=0.5000D+00*XO2+...
     &                      +    6.9000D-01 * RXRAT(   173 )      ! TERP+O3=0.6900D+00*XO2+...
     &                      +    7.5000D-01 * RXRAT(   174 )      ! TERP+NO3=0.7500D+00*XO2+...
     &                      +    4.8000D-01 * RXRAT(   192 )      ! CRES+NO3=0.4800D+00*XO2+...
     &                      +    4.5000D-01 * RXRAT(   201 )      ! XOPN+NO3=0.4500D+00*XO2+...
     &                      +                 RXRAT(   212 )      ! OPO3+C2O3=XO2+MEO2+ALDX+...
     &                      +    8.7400D-01 * RXRAT(   220 )      ! XPAR=0.8740D+00*XO2+...
     &                      +    2.0000D+00 * RXRAT(   234 )      ! CL+ETH=0.2000D+01*XO2+FMCL+...
     &                      +    2.0000D+00 * RXRAT(   235 )      ! CL+OLE=0.2000D+01*XO2+...
     &                      +    1.7000D+00 * RXRAT(   236 )      ! CL+IOLE=0.1700D+01*XO2+...
      LOSS(  XO2          ) =                 RXRAT(    79 )      ! XO2+NO=NO2
     &                      +                 RXRAT(    80 )      ! XO2+HO2=ROOH
     &                      +                 RXRAT(    81 )      ! XO2+C2O3=0.8000D+00*MEO2+...
     &                      +                 RXRAT(    82 )      ! XO2+RO2=RO2

      PROD(  XO2N         ) =    6.0000D-02 * RXRAT(    89 )      ! ROOH+OH=0.6000D-01*XO2N+...
     &                      +    9.0000D-03 * RXRAT(   125 )      ! ETHA+OH=0.9000D-02*XO2N+...
     &                      +    4.0000D-02 * RXRAT(   133 )      ! ROR=0.4000D-01*XO2N+...
     &                      +    1.0000D-02 * RXRAT(   141 )      ! OLE+O=0.1000D-01*XO2N+...
     &                      +    2.4000D-02 * RXRAT(   142 )      ! OLE+OH=0.2400D-01*XO2N+...
     &                      +    4.0000D-02 * RXRAT(   144 )      ! OLE+NO3=0.4000D-01*XO2N+...
     &                      +    4.0000D-02 * RXRAT(   148 )      ! IOLE+NO3=0.4000D-01*XO2N+...
     &                      +    3.0000D-02 * RXRAT(   157 )      ! ISOP+NO3=0.3000D-01*XO2N+...
     &                      +    2.2000D-02 * RXRAT(   158 )      ! ISPD+OH=0.2200D-01*XO2N+...
     &                      +    2.5000D-01 * RXRAT(   172 )      ! TERP+OH=0.2500D+00*XO2N+...
     &                      +    1.8000D-01 * RXRAT(   173 )      ! TERP+O3=0.1800D+00*XO2N+...
     &                      +    2.5000D-01 * RXRAT(   174 )      ! TERP+NO3=0.2500D+00*XO2N+...
     &                      +    2.0000D-02 * RXRAT(   191 )      ! CRES+OH=0.2000D-01*XO2N+...
     &                      +    1.0000D-01 * RXRAT(   192 )      ! CRES+NO3=0.1000D+00*XO2N+...
     &                      +    1.0000D-01 * RXRAT(   201 )      ! XOPN+NO3=0.1000D+00*XO2N+...
     &                      +                 RXRAT(   217 )      ! XPRP=XO2N+RO2
     &                      +                 RXRAT(   219 )      ! XPAR=XO2N+RO2
     &                      +    3.0000D-02 * RXRAT(   232 )      ! CL+PRPA=0.3000D-01*XO2N+...
     &                      +    9.0000D-03 * RXRAT(   233 )      ! CL+ETHA=0.9000D-02*XO2N+...
     &                      +    4.0000D-02 * RXRAT(   237 )      ! CL+ISOP=0.4000D-01*XO2N+...
      LOSS(  XO2N         ) =                 RXRAT(    83 )      ! XO2N+NO=0.5000D+00*NTR1+...
     &                      +                 RXRAT(    84 )      ! XO2N+HO2=ROOH
     &                      +                 RXRAT(    85 )      ! XO2N+C2O3=0.8000D+00*HO2+...
     &                      +                 RXRAT(    86 )      ! XO2N+RO2=RO2

      PROD(  NTR1         ) =    5.0000D-01 * RXRAT(    83 )      ! XO2N+NO=0.5000D+00*NTR1+...
     &                      +                 RXRAT(   135 )      ! ROR+NO2=NTR1
     &                      +    5.0000D-01 * RXRAT(   140 )      ! ETH+NO3=0.5000D+00*NTR1+...
     &                      +    5.0000D-01 * RXRAT(   144 )      ! OLE+NO3=0.5000D+00*NTR1+...
     &                      +    5.0000D-01 * RXRAT(   148 )      ! IOLE+NO3=0.5000D+00*NTR1+...
      LOSS(  NTR1         ) =                 RXRAT(    91 )      ! NTR1+OH=NTR2
     &                      +                 RXRAT(    92 )      ! NTR1=NO2

      PROD(  NTR2         ) =    5.0000D-01 * RXRAT(    83 )      ! XO2N+NO=0.5000D+00*NTR2+...
     &                      +                 RXRAT(    91 )      ! NTR1+OH=NTR2
     &                      +    6.5000D-01 * RXRAT(   157 )      ! ISOP+NO3=0.6500D+00*NTR2+...
     &                      +    1.4200D-01 * RXRAT(   160 )      ! ISPD+NO3=0.1420D+00*NTR2+...
     &                      +    2.6600D-01 * RXRAT(   170 )      ! INTR+OH=0.2660D+00*NTR2+...
     &                      +    5.3000D-01 * RXRAT(   174 )      ! TERP+NO3=0.5300D+00*NTR2+...
     &                      +    8.2000D-02 * RXRAT(   176 )      ! BZO2+NO=0.8200D-01*NTR2+...
     &                      +    1.4000D-01 * RXRAT(   181 )      ! TO2+NO=0.1400D+00*NTR2+...
     &                      +    1.4000D-01 * RXRAT(   187 )      ! XLO2+NO=0.1400D+00*NTR2+...
     &                      +                 RXRAT(   195 )      ! CRON+OH=NTR2+0.5000D+00*CRO
     &                      +                 RXRAT(   196 )      ! CRON+NO3=NTR2+0.5000D+...
     &                      +    5.0000D-01 * RXRAT(   201 )      ! XOPN+NO3=0.5000D+00*NTR2+...
     &                      +    5.0000D-01 * RXRAT(   214 )      ! OPAN+OH=0.5000D+00*NTR2+...
      LOSS(  NTR2         ) =                 RXRAT(   264 )      ! NTR2=HNO3

      PROD(  FACD         ) =                 RXRAT(   103 )      ! HCO3+NO=FACD+NO2+HO2
     &                      +    5.0000D-01 * RXRAT(   104 )      ! HCO3+HO2=0.5000D+00*FACD+...
     &                      +    3.0000D-01 * RXRAT(   136 )      ! ETHY+OH=0.3000D+00*FACD+...
     &                      +    3.7000D-01 * RXRAT(   139 )      ! ETH+O3=0.3700D+00*FACD+...
     &                      +    9.0000D-02 * RXRAT(   143 )      ! OLE+O3=0.9000D-01*FACD+...
     &                      +    1.5000D-01 * RXRAT(   159 )      ! ISPD+O3=0.1500D+00*FACD+...
     &                      +    7.4000D-02 * RXRAT(   166 )      ! EPX2+HO2=0.7400D-01*FACD+...
     &                      +    1.8500D-01 * RXRAT(   170 )      ! INTR+OH=0.1850D+00*FACD+...
      LOSS(  FACD         ) =                 RXRAT(    93 )      ! FACD+OH=HO2

      PROD(  CO           ) =                 RXRAT(    96 )      ! FORM+OH=CO+HO2
     &                      +                 RXRAT(    97 )      ! FORM=CO+0.2000D+01*HO2
     &                      +                 RXRAT(    98 )      ! FORM=CO
     &                      +                 RXRAT(    99 )      ! FORM+O=CO+HO2+OH
     &                      +                 RXRAT(   100 )      ! FORM+NO3=CO+HO2+HNO3
     &                      +                 RXRAT(   108 )      ! ALD2=CO+RO2+MEO2+HO2
     &                      +                 RXRAT(   112 )      ! ALDX=CO+XO2H+RO2+ALD2+HO2
     &                      +    8.9000D-01 * RXRAT(   114 )      ! GLYD=0.8900D+00*CO+0.7400D+...
     &                      +    1.8000D+00 * RXRAT(   116 )      ! GLY+OH=0.1800D+01*CO+...
     &                      +    2.0000D+00 * RXRAT(   117 )      ! GLY=0.2000D+01*CO+0.2000D+...
     &                      +    1.5000D+00 * RXRAT(   118 )      ! GLY+NO3=0.1500D+01*CO+HNO3+...
     &                      +                 RXRAT(   119 )      ! MGLY=CO+HO2+C2O3
     &                      +                 RXRAT(   121 )      ! MGLY+OH=CO+C2O3
     &                      +    3.8000D-01 * RXRAT(   129 )      ! ACET=0.3800D+00*CO+0.1380D+...
     &                      +    3.0000D-01 * RXRAT(   136 )      ! ETHY+OH=0.3000D+00*CO+...
     &                      +                 RXRAT(   137 )      ! ETH+O=CO+HO2+FORM+0.7000D+...
     &                      +    5.1000D-01 * RXRAT(   139 )      ! ETH+O3=0.5100D+00*CO+FORM+...
     &                      +    2.0000D-01 * RXRAT(   141 )      ! OLE+O=0.2000D+00*CO+...
     &                      +    3.7800D-01 * RXRAT(   143 )      ! OLE+O3=0.3780D+00*CO+...
     &                      +    1.0000D-01 * RXRAT(   145 )      ! IOLE+O=0.1000D+00*CO+...
     &                      +    2.4500D-01 * RXRAT(   147 )      ! IOLE+O3=0.2450D+00*CO+...
     &                      +    6.6000D-02 * RXRAT(   156 )      ! ISOP+O3=0.6600D-01*CO+...
     &                      +    1.3700D-01 * RXRAT(   158 )      ! ISPD+OH=0.1370D+00*CO+...
     &                      +    5.4300D-01 * RXRAT(   159 )      ! ISPD+O3=0.5430D+00*CO+...
     &                      +    2.5100D-01 * RXRAT(   166 )      ! EPX2+HO2=0.2510D+00*CO+...
     &                      +    2.5100D-01 * RXRAT(   167 )      ! EPX2+NO=0.2510D+00*CO+...
     &                      +    2.0000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.2000D+00*CO+...
     &                      +    2.5100D-01 * RXRAT(   169 )      ! EPX2+RO2=0.2510D+00*CO+...
     &                      +    1.0000D-03 * RXRAT(   173 )      ! TERP+O3=0.1000D-02*CO+...
     &                      +    7.0000D-01 * RXRAT(   198 )      ! XOPN=0.7000D+00*CO+XO2H+...
     &                      +    5.0000D-01 * RXRAT(   200 )      ! XOPN+O3=0.5000D+00*CO+...
     &                      +                 RXRAT(   202 )      ! OPEN=CO+HO2+OPO3
     &                      +    1.9800D+00 * RXRAT(   204 )      ! OPEN+O3=0.1980D+01*CO+...
     &                      +    5.0000D-01 * RXRAT(   208 )      ! OPO3+NO=0.5000D+00*CO+...
     &                      +                 RXRAT(   214 )      ! OPAN+OH=CO+0.5000D+00*GLY+...
     &                      +                 RXRAT(   228 )      ! OH+FMCL=CO+CL
     &                      +                 RXRAT(   229 )      ! FMCL=CO+CL+HO2
     &                      +                 RXRAT(   238 )      ! CL+FORM=CO+HO2+HCL
      LOSS(  CO           ) =                 RXRAT(   123 )      ! CO+OH=HO2

      PROD(  HCO3         ) =                 RXRAT(   101 )      ! FORM+HO2=HCO3
      LOSS(  HCO3         ) =                 RXRAT(   102 )      ! HCO3=FORM+HO2
     &                      +                 RXRAT(   103 )      ! HCO3+NO=FACD+NO2+HO2
     &                      +                 RXRAT(   104 )      ! HCO3+HO2=0.5000D+00*MEPX+...

      PROD(  ALDX         ) =    3.7000D-01 * RXRAT(   133 )      ! ROR=0.3700D+00*ALDX+...
     &                      +    3.0000D-01 * RXRAT(   141 )      ! OLE+O=0.3000D+00*ALDX+...
     &                      +    4.8800D-01 * RXRAT(   142 )      ! OLE+OH=0.4880D+00*ALDX+...
     &                      +    2.7000D-01 * RXRAT(   143 )      ! OLE+O3=0.2700D+00*ALDX+...
     &                      +    3.7500D-01 * RXRAT(   144 )      ! OLE+NO3=0.3750D+00*ALDX+...
     &                      +    6.6000D-01 * RXRAT(   145 )      ! IOLE+O=0.6600D+00*ALDX+...
     &                      +    7.0000D-01 * RXRAT(   146 )      ! IOLE+OH=0.7000D+00*ALDX+...
     &                      +    4.4200D-01 * RXRAT(   147 )      ! IOLE+O3=0.4420D+00*ALDX+...
     &                      +    6.2500D-01 * RXRAT(   148 )      ! IOLE+NO3=0.6250D+00*ALDX+...
     &                      +    1.5000D-01 * RXRAT(   156 )      ! ISOP+O3=0.1500D+00*ALDX+...
     &                      +    2.9000D-02 * RXRAT(   162 )      ! ISPX+OH=0.2900D-01*ALDX+...
     &                      +    7.8000D-02 * RXRAT(   170 )      ! INTR+OH=0.7800D-01*ALDX+...
     &                      +    1.5000D-01 * RXRAT(   171 )      ! TERP+O=0.1500D+00*ALDX+...
     &                      +    4.7000D-01 * RXRAT(   172 )      ! TERP+OH=0.4700D+00*ALDX+...
     &                      +    2.1000D-01 * RXRAT(   173 )      ! TERP+O3=0.2100D+00*ALDX+...
     &                      +    4.7000D-01 * RXRAT(   174 )      ! TERP+NO3=0.4700D+00*ALDX+...
     &                      +    4.4000D-01 * RXRAT(   211 )      ! OPO3+HO2=0.4400D+00*ALDX+...
     &                      +                 RXRAT(   212 )      ! OPO3+C2O3=ALDX+XO2+MEO2+...
     &                      +    8.0000D-01 * RXRAT(   213 )      ! OPO3+RO2=0.8000D+00*ALDX+...
     &                      +    2.6800D-01 * RXRAT(   218 )      ! XPRP=0.2680D+00*ALDX+...
     &                      +    1.2600D-01 * RXRAT(   220 )      ! XPAR=0.1260D+00*ALDX+...
     &                      +    6.7000D-01 * RXRAT(   235 )      ! CL+OLE=0.6700D+00*ALDX+...
     &                      +    5.5000D-01 * RXRAT(   236 )      ! CL+IOLE=0.5500D+00*ALDX+...
      LOSS(  ALDX         ) =                 RXRAT(   109 )      ! ALDX+O=CXO3+OH
     &                      +                 RXRAT(   110 )      ! ALDX+OH=CXO3
     &                      +                 RXRAT(   111 )      ! ALDX+NO3=CXO3+HNO3
     &                      +                 RXRAT(   112 )      ! ALDX=ALD2+XO2H+RO2+CO+HO2
     &                      +                 RXRAT(   240 )      ! ALDX+CL=HCL+CXO3

      PROD(  GLYD         ) =    1.1000D-02 * RXRAT(   127 )      ! ETOH+OH=0.1100D-01*GLYD+...
     &                      +    2.2000D-01 * RXRAT(   138 )      ! ETH+OH=0.2200D+00*GLYD+RO2+...
     &                      +    2.6900D-01 * RXRAT(   158 )      ! ISPD+OH=0.2690D+00*GLYD+...
     &                      +    1.1300D-01 * RXRAT(   160 )      ! ISPD+NO3=0.1130D+00*GLYD+...
     &                      +    1.2800D-01 * RXRAT(   161 )      ! ISPD=0.1280D+00*GLYD+...
     &                      +    2.7500D-01 * RXRAT(   166 )      ! EPX2+HO2=0.2750D+00*GLYD+...
     &                      +    2.7500D-01 * RXRAT(   167 )      ! EPX2+NO=0.2750D+00*GLYD+...
     &                      +    2.2000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.2200D+00*GLYD+...
     &                      +    2.7500D-01 * RXRAT(   169 )      ! EPX2+RO2=0.2750D+00*GLYD+...
     &                      +    3.3100D-01 * RXRAT(   170 )      ! INTR+OH=0.3310D+00*GLYD+...
      LOSS(  GLYD         ) =                 RXRAT(   113 )      ! GLYD+OH=0.2000D+00*GLY+...
     &                      +                 RXRAT(   114 )      ! GLYD=0.7400D+00*FORM+...
     &                      +                 RXRAT(   115 )      ! GLYD+NO3=HNO3+C2O3

      PROD(  GLY          ) =    2.0000D-01 * RXRAT(   113 )      ! GLYD+OH=0.2000D+00*GLY+...
     &                      +    1.1000D-01 * RXRAT(   114 )      ! GLYD=0.1100D+00*GLY+...
     &                      +    7.0000D-01 * RXRAT(   136 )      ! ETHY+OH=0.7000D+00*GLY+...
     &                      +    7.5000D-02 * RXRAT(   143 )      ! OLE+O3=0.7500D-01*GLY+...
     &                      +    2.4000D-01 * RXRAT(   147 )      ! IOLE+O3=0.2400D+00*GLY+...
     &                      +    1.7000D-01 * RXRAT(   159 )      ! ISPD+O3=0.1700D+00*GLY+...
     &                      +    2.7500D-01 * RXRAT(   166 )      ! EPX2+HO2=0.2750D+00*GLY+...
     &                      +    2.7500D-01 * RXRAT(   167 )      ! EPX2+NO=0.2750D+00*GLY+...
     &                      +    2.2000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.2200D+00*GLY+...
     &                      +    2.7500D-01 * RXRAT(   169 )      ! EPX2+RO2=0.2750D+00*GLY+...
     &                      +    9.1800D-01 * RXRAT(   176 )      ! BZO2+NO=0.9180D+00*GLY+...
     &                      +                 RXRAT(   177 )      ! BZO2+C2O3=GLY+OPEN+HO2+...
     &                      +                 RXRAT(   179 )      ! BZO2+RO2=GLY+OPEN+HO2+RO2
     &                      +    4.1700D-01 * RXRAT(   181 )      ! TO2+NO=0.4170D+00*GLY+...
     &                      +    4.8000D-01 * RXRAT(   182 )      ! TO2+C2O3=0.4800D+00*GLY+...
     &                      +    4.8000D-01 * RXRAT(   184 )      ! TO2+RO2=0.4800D+00*GLY+...
     &                      +    2.2100D-01 * RXRAT(   187 )      ! XLO2+NO=0.2210D+00*GLY+...
     &                      +    2.6000D-01 * RXRAT(   189 )      ! XLO2+C2O3=0.2600D+00*GLY+...
     &                      +    2.6000D-01 * RXRAT(   190 )      ! XLO2+RO2=0.2600D+00*GLY+...
     &                      +    2.5000D-02 * RXRAT(   191 )      ! CRES+OH=0.2500D-01*GLY+...
     &                      +    2.4000D-01 * RXRAT(   192 )      ! CRES+NO3=0.2400D+00*GLY+...
     &                      +    4.0000D-01 * RXRAT(   198 )      ! XOPN=0.4000D+00*GLY+XO2H+...
     &                      +    4.0000D-01 * RXRAT(   199 )      ! XOPN+OH=0.4000D+00*GLY+...
     &                      +    4.0000D-01 * RXRAT(   203 )      ! OPEN+OH=0.4000D+00*GLY+...
     &                      +    1.4000D+00 * RXRAT(   204 )      ! OPEN+O3=0.1400D+01*GLY+...
     &                      +    5.0000D-01 * RXRAT(   208 )      ! OPO3+NO=0.5000D+00*GLY+NO2+...
     &                      +    5.0000D-01 * RXRAT(   214 )      ! OPAN+OH=0.5000D+00*GLY+...
      LOSS(  GLY          ) =                 RXRAT(   116 )      ! GLY+OH=0.1800D+01*CO+...
     &                      +                 RXRAT(   117 )      ! GLY=0.2000D+01*HO2+0.2000D+...
     &                      +                 RXRAT(   118 )      ! GLY+NO3=HNO3+0.1500D+01*CO+...
     &                      +                 RXRAT(   275 )      ! GLY=AGLYJ

      PROD(  MGLY         ) =    7.5000D-02 * RXRAT(   143 )      ! OLE+O3=0.7500D-01*MGLY+...
     &                      +    6.0000D-02 * RXRAT(   147 )      ! IOLE+O3=0.6000D-01*MGLY+...
     &                      +    1.1500D-01 * RXRAT(   158 )      ! ISPD+OH=0.1150D+00*MGLY+...
     &                      +    5.3100D-01 * RXRAT(   159 )      ! ISPD+O3=0.5310D+00*MGLY+...
     &                      +    1.1300D-01 * RXRAT(   160 )      ! ISPD+NO3=0.1130D+00*MGLY+...
     &                      +    2.7500D-01 * RXRAT(   166 )      ! EPX2+HO2=0.2750D+00*MGLY+...
     &                      +    2.7500D-01 * RXRAT(   167 )      ! EPX2+NO=0.2750D+00*MGLY+...
     &                      +    2.2000D-01 * RXRAT(   168 )      ! EPX2+C2O3=0.2200D+00*MGLY+...
     &                      +    2.7500D-01 * RXRAT(   169 )      ! EPX2+RO2=0.2750D+00*MGLY+...
     &                      +    4.4300D-01 * RXRAT(   181 )      ! TO2+NO=0.4430D+00*MGLY+...
     &                      +    5.2000D-01 * RXRAT(   182 )      ! TO2+C2O3=0.5200D+00*MGLY+...
     &                      +    5.2000D-01 * RXRAT(   184 )      ! TO2+RO2=0.5200D+00*MGLY+...
     &                      +    6.7500D-01 * RXRAT(   187 )      ! XLO2+NO=0.6750D+00*MGLY+...
     &                      +    7.7000D-01 * RXRAT(   189 )      ! XLO2+C2O3=0.7700D+00*MGLY+...
     &                      +    7.7000D-01 * RXRAT(   190 )      ! XLO2+RO2=0.7700D+00*MGLY+...
     &                      +    2.4000D-01 * RXRAT(   192 )      ! CRES+NO3=0.2400D+00*MGLY+...
     &                      +                 RXRAT(   199 )      ! XOPN+OH=MGLY+0.4000D+...
     &                      +    1.2000D+00 * RXRAT(   200 )      ! XOPN+O3=0.1200D+01*MGLY+...
     &                      +    2.5000D-01 * RXRAT(   201 )      ! XOPN+NO3=0.2500D+00*MGLY+...
     &                      +    2.4000D-01 * RXRAT(   204 )      ! OPEN+O3=0.2400D+00*MGLY+...
      LOSS(  MGLY         ) =                 RXRAT(   119 )      ! MGLY=C2O3+HO2+CO
     &                      +                 RXRAT(   120 )      ! MGLY+NO3=HNO3+C2O3+XO2+RO2
     &                      +                 RXRAT(   121 )      ! MGLY+OH=C2O3+CO
     &                      +                 RXRAT(   276 )      ! MGLY=AGLYJ

      PROD(  ETHA         ) =   0.0D0
      LOSS(  ETHA         ) =                 RXRAT(   125 )      ! ETHA+OH=0.9910D+00*ALD2+...
     &                      +                 RXRAT(   233 )      ! ETHA+CL=HCL+0.9910D+...

      PROD(  ETOH         ) =   0.0D0
      LOSS(  ETOH         ) =                 RXRAT(   127 )      ! ETOH+OH=0.9500D+00*ALD2+...
     &                      +                 RXRAT(   242 )      ! ETOH+CL=HCL+HO2+ALD2

      PROD(  KET          ) =    2.0000D-01 * RXRAT(   133 )      ! ROR=0.2000D+00*KET+0.4200D+...
     &                      +                 RXRAT(   134 )      ! ROR=KET+HO2
      LOSS(  KET          ) =                 RXRAT(   128 )      ! KET=0.5000D+00*ALD2+...

      PROD(  PAR          ) =    2.0000D-01 * RXRAT(   141 )      ! OLE+O=0.2000D+00*PAR+...
     &                      +    1.0000D-01 * RXRAT(   145 )      ! IOLE+O=0.1000D+00*PAR+...
     &                      +    2.9000D-01 * RXRAT(   147 )      ! IOLE+O3=0.2900D+00*PAR+...
     &                      +                 RXRAT(   148 )      ! IOLE+NO3=PAR+0.5000D+...
     &                      +    2.5000D-01 * RXRAT(   150 )      ! ISOP+O=0.2500D+00*PAR+...
     &                      +    3.5000D-01 * RXRAT(   156 )      ! ISOP+O3=0.3500D+00*PAR+...
     &                      +    1.1700D-01 * RXRAT(   158 )      ! ISPD+OH=0.1170D+00*PAR+...
     &                      +    7.1700D-01 * RXRAT(   160 )      ! ISPD+NO3=0.7170D+00*PAR+...
     &                      +    2.4000D-01 * RXRAT(   161 )      ! ISPD=0.2400D+00*PAR+...
     &                      +    2.1750D+00 * RXRAT(   166 )      ! EPX2+HO2=0.2175D+01*PAR+...
     &                      +    2.1750D+00 * RXRAT(   167 )      ! EPX2+NO=0.2175D+01*PAR+...
     &                      +    1.7400D+00 * RXRAT(   168 )      ! EPX2+C2O3=0.1740D+01*PAR+...
     &                      +    2.1750D+00 * RXRAT(   169 )      ! EPX2+RO2=0.2175D+01*PAR+...
     &                      +    2.7000D+00 * RXRAT(   170 )      ! INTR+OH=0.2700D+01*PAR+...
     &                      +    5.1200D+00 * RXRAT(   171 )      ! TERP+O=0.5120D+01*PAR+...
     &                      +    1.6600D+00 * RXRAT(   172 )      ! TERP+OH=0.1660D+01*PAR+...
     &                      +    7.0000D+00 * RXRAT(   173 )      ! TERP+O3=0.7000D+01*PAR+...
     &                      +    2.6800D-01 * RXRAT(   218 )      ! XPRP=0.2680D+00*PAR+...
     &                      +    3.0000D-01 * RXRAT(   236 )      ! CL+IOLE=0.3000D+00*PAR+...
      LOSS(  PAR          ) =    2.5000D+00 * RXRAT(   128 )      ! KET=-0.2500D+01*PAR+...
     &                      +                 RXRAT(   132 )      ! PAR+OH=XPAR
     &                      +    2.7000D+00 * RXRAT(   133 )      ! ROR=-0.2700D+01*PAR+...
     &                      +    7.3000D-01 * RXRAT(   142 )      ! OLE+OH=-0.7300D+00*PAR+...
     &                      +    7.9000D-01 * RXRAT(   143 )      ! OLE+O3=-0.7900D+00*PAR+...
     &                      +                 RXRAT(   144 )      ! OLE+NO3=-PAR+0.5000D+...
     &                      +    1.2600D-01 * RXRAT(   220 )      ! XPAR=-0.1260D+00*PAR+...
     &                      +                 RXRAT(   231 )      ! PAR+CL=HCL+XPAR
     &                      +                 RXRAT(   235 )      ! CL+OLE=-PAR+0.3300D+...

      PROD(  ACET         ) =    4.2000D-01 * RXRAT(   133 )      ! ROR=0.4200D+00*ACET+...
     &                      +    1.3700D-01 * RXRAT(   158 )      ! ISPD+OH=0.1370D+00*ACET+...
     &                      +    1.7000D-01 * RXRAT(   159 )      ! ISPD+O3=0.1700D+00*ACET+...
     &                      +    1.7000D-01 * RXRAT(   161 )      ! ISPD=0.1700D+00*ACET+...
     &                      +    7.3200D-01 * RXRAT(   218 )      ! XPRP=0.7320D+00*ACET+...
     &                      +                 RXRAT(   232 )      ! CL+PRPA=ACET+HCL+0.9700D+...
      LOSS(  ACET         ) =                 RXRAT(   129 )      ! ACET=0.3800D+00*CO+0.1380D+...
     &                      +                 RXRAT(   130 )      ! ACET+OH=FORM+C2O3+XO2+RO2

      PROD(  PRPA         ) =   0.0D0
      LOSS(  PRPA         ) =                 RXRAT(   131 )      ! PRPA+OH=XPRP
     &                      +                 RXRAT(   232 )      ! PRPA+CL=HCL+ACET+0.9700D+...

      PROD(  XPRP         ) =                 RXRAT(   131 )      ! PRPA+OH=XPRP
      LOSS(  XPRP         ) =                 RXRAT(   217 )      ! XPRP=XO2N+RO2
     &                      +                 RXRAT(   218 )      ! XPRP=0.7320D+00*ACET+...

      PROD(  XPAR         ) =                 RXRAT(   132 )      ! PAR+OH=XPAR
     &                      +                 RXRAT(   231 )      ! CL+PAR=XPAR+HCL
      LOSS(  XPAR         ) =                 RXRAT(   219 )      ! XPAR=XO2N+RO2
     &                      +                 RXRAT(   220 )      ! XPAR=0.1260D+00*ALDX+...

      PROD(  ROR          ) =    8.7400D-01 * RXRAT(   220 )      ! XPAR=0.8740D+00*ROR+...
      LOSS(  ROR          ) =    9.8000D-01 * RXRAT(   133 )      ! ROR=0.2000D-01*ROR+0.4200D+...
     &                      +                 RXRAT(   134 )      ! ROR=KET+HO2
     &                      +                 RXRAT(   135 )      ! ROR+NO2=NTR1

      PROD(  ETHY         ) =   0.0D0
      LOSS(  ETHY         ) =                 RXRAT(   136 )      ! ETHY+OH=0.7000D+00*GLY+...

      PROD(  ETH          ) =   0.0D0
      LOSS(  ETH          ) =                 RXRAT(   137 )      ! ETH+O=FORM+HO2+CO+0.7000D+...
     &                      +                 RXRAT(   138 )      ! ETH+OH=XO2H+RO2+0.1560D+...
     &                      +                 RXRAT(   139 )      ! ETH+O3=FORM+0.5100D+00*CO+...
     &                      +                 RXRAT(   140 )      ! ETH+NO3=0.5000D+00*NO2+...
     &                      +                 RXRAT(   234 )      ! ETH+CL=FMCL+0.2000D+01*XO2+...

      PROD(  OLE          ) =    2.4000D-01 * RXRAT(   161 )      ! ISPD=0.2400D+00*OLE+...
     &                      +    9.8000D-02 * RXRAT(   170 )      ! INTR+OH=0.9800D-01*OLE+...
     &                      +    3.0000D-01 * RXRAT(   236 )      ! CL+IOLE=0.3000D+00*OLE+...
      LOSS(  OLE          ) =                 RXRAT(   141 )      ! OLE+O=0.2000D+00*ALD2+...
     &                      +                 RXRAT(   142 )      ! OLE+OH=0.7810D+00*FORM+...
     &                      +                 RXRAT(   143 )      ! OLE+O3=0.2950D+00*ALD2+...
     &                      +                 RXRAT(   144 )      ! OLE+NO3=0.5000D+00*NO2+...
     &                      +                 RXRAT(   235 )      ! OLE+CL=FMCL+0.3300D+...

      PROD(  IOLE         ) =    2.9000D-02 * RXRAT(   162 )      ! ISPX+OH=0.2900D-01*IOLE+...
      LOSS(  IOLE         ) =                 RXRAT(   145 )      ! IOLE+O=0.1240D+01*ALD2+...
     &                      +                 RXRAT(   146 )      ! IOLE+OH=0.1300D+01*ALD2+...
     &                      +                 RXRAT(   147 )      ! IOLE+O3=0.7320D+00*ALD2+...
     &                      +                 RXRAT(   148 )      ! IOLE+NO3=0.5000D+00*NO2+...
     &                      +                 RXRAT(   236 )      ! IOLE+CL=0.3000D+00*HCL+...

      PROD(  ISOP         ) =   0.0D0
      LOSS(  ISOP         ) =                 RXRAT(   149 )      ! ISOP+OH=ISO2+RO2+ISOPRXN
     &                      +                 RXRAT(   150 )      ! ISOP+O=0.7500D+00*ISPD+...
     &                      +                 RXRAT(   156 )      ! ISOP+O3=0.6000D+00*FORM+...
     &                      +                 RXRAT(   157 )      ! ISOP+NO3=0.3500D+00*NO2+...
     &                      +                 RXRAT(   237 )      ! ISOP+CL=FMCL+ISPD+0.9600D+...

      PROD(  ISO2         ) =                 RXRAT(   149 )      ! ISOP+OH=ISO2+RO2+ISOPRXN
     &                      +    6.7000D-02 * RXRAT(   162 )      ! ISPX+OH=0.6700D-01*ISO2+...
      LOSS(  ISO2         ) =                 RXRAT(   151 )      ! ISO2+NO=0.1000D+00*INTR+...
     &                      +                 RXRAT(   152 )      ! ISO2+HO2=0.8800D+00*ISPX+...
     &                      +                 RXRAT(   153 )      ! ISO2+C2O3=0.5980D+00*FORM+...
     &                      +                 RXRAT(   154 )      ! ISO2+RO2=0.5980D+00*FORM+...
     &                      +                 RXRAT(   155 )      ! ISO2=HO2+HPLD

      PROD(  ISOPRXN      ) =                 RXRAT(   149 )      ! ISOP+OH=ISOPRXN+RO2+ISO2
     &                      +                 RXRAT(   157 )      ! ISOP+NO3=ISOPRXN+0.6500D+...
      LOSS(  ISOPRXN      ) =   0.0D0

      PROD(  ISPD         ) =    7.5000D-01 * RXRAT(   150 )      ! ISOP+O=0.7500D+00*ISPD+...
     &                      +    9.0000D-01 * RXRAT(   151 )      ! ISO2+NO=0.9000D+00*ISPD+...
     &                      +    1.2000D-01 * RXRAT(   152 )      ! ISO2+HO2=0.1200D+00*ISPD+...
     &                      +                 RXRAT(   153 )      ! ISO2+C2O3=ISPD+0.5980D+...
     &                      +                 RXRAT(   154 )      ! ISO2+RO2=ISPD+0.5980D+...
     &                      +    6.5000D-01 * RXRAT(   156 )      ! ISOP+O3=0.6500D+00*ISPD+...
     &                      +    3.5000D-01 * RXRAT(   157 )      ! ISOP+NO3=0.3500D+00*ISPD+...
     &                      +                 RXRAT(   163 )      ! HPLD=ISPD+OH
     &                      +                 RXRAT(   164 )      ! HPLD+NO3=ISPD+HNO3
     &                      +                 RXRAT(   237 )      ! CL+ISOP=ISPD+FMCL+0.9600D+...
      LOSS(  ISPD         ) =                 RXRAT(   158 )      ! ISPD+OH=0.2200D-01*XO2N+...
     &                      +                 RXRAT(   159 )      ! ISPD+O3=0.4000D-01*ALD2+...
     &                      +                 RXRAT(   160 )      ! ISPD+NO3=0.7170D+00*HNO3+...
     &                      +                 RXRAT(   161 )      ! ISPD=0.7600D+00*HO2+...

      PROD(  INTR         ) =    1.0000D-01 * RXRAT(   151 )      ! ISO2+NO=0.1000D+00*INTR+...
      LOSS(  INTR         ) =    8.9600D-01 * RXRAT(   170 )      ! INTR+OH=0.1040D+00*INTR+...

      PROD(  ISPX         ) =    8.8000D-01 * RXRAT(   152 )      ! ISO2+HO2=0.8800D+00*ISPX+...
      LOSS(  ISPX         ) =                 RXRAT(   162 )      ! ISPX+OH=0.9040D+00*EPOX+...

      PROD(  HPLD         ) =                 RXRAT(   155 )      ! ISO2=HPLD+HO2
      LOSS(  HPLD         ) =                 RXRAT(   163 )      ! HPLD=OH+ISPD
     &                      +                 RXRAT(   164 )      ! HPLD+NO3=HNO3+ISPD

      PROD(  OPO3         ) =    4.5700D-01 * RXRAT(   158 )      ! ISPD+OH=0.4570D+00*OPO3+...
     &                      +    4.8000D-01 * RXRAT(   192 )      ! CRES+NO3=0.4800D+00*OPO3+...
     &                      +                 RXRAT(   202 )      ! OPEN=OPO3+HO2+CO
     &                      +    6.0000D-01 * RXRAT(   203 )      ! OPEN+OH=0.6000D+00*OPO3+...
     &                      +                 RXRAT(   205 )      ! OPEN+NO3=OPO3+HNO3
     &                      +                 RXRAT(   210 )      ! OPAN=OPO3+NO2
      LOSS(  OPO3         ) =                 RXRAT(   208 )      ! OPO3+NO=NO2+0.5000D+00*GLY+...
     &                      +                 RXRAT(   209 )      ! OPO3+NO2=OPAN
     &                      +                 RXRAT(   211 )      ! OPO3+HO2=0.4100D+00*PACD+...
     &                      +                 RXRAT(   212 )      ! OPO3+C2O3=MEO2+XO2+ALDX+...
     &                      +                 RXRAT(   213 )      ! OPO3+RO2=0.8000D+00*XO2H+...

      PROD(  EPOX         ) =    9.0400D-01 * RXRAT(   162 )      ! ISPX+OH=0.9040D+00*EPOX+...
      LOSS(  EPOX         ) =                 RXRAT(   165 )      ! EPOX+OH=EPX2+RO2
     &                      +                 RXRAT(   274 )      ! EPOX=AISO3J

      PROD(  EPX2         ) =                 RXRAT(   165 )      ! EPOX+OH=EPX2+RO2
      LOSS(  EPX2         ) =                 RXRAT(   166 )      ! EPX2+HO2=0.2750D+00*GLYD+...
     &                      +                 RXRAT(   167 )      ! EPX2+NO=0.2750D+00*GLYD+...
     &                      +                 RXRAT(   168 )      ! EPX2+C2O3=0.2200D+00*GLYD+...
     &                      +                 RXRAT(   169 )      ! EPX2+RO2=0.2750D+00*GLYD+...

      PROD(  TERP         ) =   0.0D0
      LOSS(  TERP         ) =                 RXRAT(   171 )      ! TERP+O=0.1500D+00*ALDX+...
     &                      +                 RXRAT(   172 )      ! TERP+OH=0.7500D+00*XO2H+...
     &                      +                 RXRAT(   173 )      ! TERP+O3=0.5700D+00*OH+...
     &                      +                 RXRAT(   174 )      ! TERP+NO3=0.4700D+00*NO2+...

      PROD(  TRPRXN       ) =                 RXRAT(   171 )      ! TERP+O=TRPRXN+0.5120D+...
     &                      +                 RXRAT(   172 )      ! TERP+OH=TRPRXN+0.5000D+...
     &                      +                 RXRAT(   173 )      ! TERP+O3=TRPRXN+0.7000D-...
     &                      +                 RXRAT(   174 )      ! TERP+NO3=TRPRXN+0.2800D+...
      LOSS(  TRPRXN       ) =   0.0D0

      PROD(  BENZENE      ) =   0.0D0
      LOSS(  BENZENE      ) =                 RXRAT(   175 )      ! BENZENE+OH=0.5300D+00*CRES+...

      PROD(  CRES         ) =    5.3000D-01 * RXRAT(   175 )      ! BENZENE+OH=0.5300D+00*CRES+...
     &                      +    1.8000D-01 * RXRAT(   180 )      ! TOL+OH=0.1800D+00*CRES+...
     &                      +    1.5500D-01 * RXRAT(   185 )      ! XYLMN+OH=0.1550D+00*CRES+...
     &                      +    1.5500D-01 * RXRAT(   186 )      ! NAPH+OH=0.1550D+00*CRES+...
     &                      +                 RXRAT(   194 )      ! CRO+HO2=CRES
     &                      +    1.8000D-01 * RXRAT(   244 )      ! CL+TOL=0.1800D+00*CRES+HCL+...
     &                      +    1.5500D-01 * RXRAT(   245 )      ! CL+XYLMN=0.1550D+00*CRES+...
     &                      +    1.5500D-01 * RXRAT(   246 )      ! CL+NAPH=0.1550D+00*CRES+...
      LOSS(  CRES         ) =                 RXRAT(   191 )      ! CRES+OH=0.2500D-01*GLY+...
     &                      +                 RXRAT(   192 )      ! CRES+NO3=0.3000D+00*CRO+...

      PROD(  BZO2         ) =    3.5200D-01 * RXRAT(   175 )      ! BENZENE+OH=0.3520D+00*BZO2+...
      LOSS(  BZO2         ) =                 RXRAT(   176 )      ! BZO2+NO=0.9180D+00*NO2+...
     &                      +                 RXRAT(   177 )      ! BZO2+C2O3=GLY+OPEN+HO2+...
     &                      +                 RXRAT(   178 )      ! BZO2+HO2=
     &                      +                 RXRAT(   179 )      ! BZO2+RO2=GLY+OPEN+HO2+RO2

      PROD(  OPEN         ) =    1.1800D-01 * RXRAT(   175 )      ! BENZENE+OH=0.1180D+00*OPEN+...
     &                      +    9.1800D-01 * RXRAT(   176 )      ! BZO2+NO=0.9180D+00*OPEN+...
     &                      +                 RXRAT(   177 )      ! BZO2+C2O3=OPEN+GLY+HO2+...
     &                      +                 RXRAT(   179 )      ! BZO2+RO2=OPEN+GLY+HO2+RO2
     &                      +    1.0000D-01 * RXRAT(   180 )      ! TOL+OH=0.1000D+00*OPEN+...
     &                      +    6.6000D-01 * RXRAT(   181 )      ! TO2+NO=0.6600D+00*OPEN+...
     &                      +    7.7000D-01 * RXRAT(   182 )      ! TO2+C2O3=0.7700D+00*OPEN+...
     &                      +    7.7000D-01 * RXRAT(   184 )      ! TO2+RO2=0.7700D+00*OPEN+...
     &                      +    3.0000D-01 * RXRAT(   187 )      ! XLO2+NO=0.3000D+00*OPEN+...
     &                      +    3.5000D-01 * RXRAT(   189 )      ! XLO2+C2O3=0.3500D+00*OPEN+...
     &                      +    3.5000D-01 * RXRAT(   190 )      ! XLO2+RO2=0.3500D+00*OPEN+...
     &                      +    2.5000D-02 * RXRAT(   191 )      ! CRES+OH=0.2500D-01*OPEN+...
     &                      +                 RXRAT(   197 )      ! CRON=OPEN+HO2+FORM+HONO
     &                      +    2.5000D-01 * RXRAT(   201 )      ! XOPN+NO3=0.2500D+00*OPEN+...
     &                      +    1.0000D-01 * RXRAT(   244 )      ! CL+TOL=0.1000D+00*OPEN+...
      LOSS(  OPEN         ) =                 RXRAT(   202 )      ! OPEN=OPO3+HO2+CO
     &                      +                 RXRAT(   203 )      ! OPEN+OH=0.6000D+00*OPO3+...
     &                      +                 RXRAT(   204 )      ! OPEN+O3=0.1400D+01*GLY+...
     &                      +                 RXRAT(   205 )      ! OPEN+NO3=OPO3+HNO3

      PROD(  BENZRO2      ) =                 RXRAT(   175 )      ! BENZENE+OH=BENZRO2+0.3520D+...
      LOSS(  BENZRO2      ) =                 RXRAT(   256 )      ! BENZRO2+NO=NO+BNZNRXN
     &                      +                 RXRAT(   257 )      ! BENZRO2+HO2=HO2+BNZHRXN

      PROD(  TOL          ) =   0.0D0
      LOSS(  TOL          ) =                 RXRAT(   180 )      ! TOL+OH=0.1800D+00*CRES+...
     &                      +                 RXRAT(   244 )      ! TOL+CL=HCL+0.1800D+00*CRES+...

      PROD(  TO2          ) =    6.5000D-01 * RXRAT(   180 )      ! TOL+OH=0.6500D+00*TO2+...
     &                      +    6.5000D-01 * RXRAT(   244 )      ! CL+TOL=0.6500D+00*TO2+...
      LOSS(  TO2          ) =                 RXRAT(   181 )      ! TO2+NO=0.8600D+00*NO2+...
     &                      +                 RXRAT(   182 )      ! TO2+C2O3=0.4800D+00*GLY+...
     &                      +                 RXRAT(   183 )      ! TO2+HO2=
     &                      +                 RXRAT(   184 )      ! TO2+RO2=0.4800D+00*GLY+...

      PROD(  TOLRO2       ) =                 RXRAT(   180 )      ! TOL+OH=TOLRO2+0.6500D+...
     &                      +                 RXRAT(   244 )      ! CL+TOL=TOLRO2+0.1800D+...
      LOSS(  TOLRO2       ) =                 RXRAT(   252 )      ! TOLRO2+NO=NO+TOLNRXN
     &                      +                 RXRAT(   253 )      ! TOLRO2+HO2=HO2+TOLHRXN

      PROD(  XOPN         ) =    2.0000D-01 * RXRAT(   181 )      ! TO2+NO=0.2000D+00*XOPN+...
     &                      +    2.3000D-01 * RXRAT(   182 )      ! TO2+C2O3=0.2300D+00*XOPN+...
     &                      +    2.3000D-01 * RXRAT(   184 )      ! TO2+RO2=0.2300D+00*XOPN+...
     &                      +    2.4400D-01 * RXRAT(   185 )      ! XYLMN+OH=0.2440D+00*XOPN+...
     &                      +    2.4400D-01 * RXRAT(   186 )      ! NAPH+OH=0.2440D+00*XOPN+...
     &                      +    5.6000D-01 * RXRAT(   187 )      ! XLO2+NO=0.5600D+00*XOPN+...
     &                      +    6.5000D-01 * RXRAT(   189 )      ! XLO2+C2O3=0.6500D+00*XOPN+...
     &                      +    6.5000D-01 * RXRAT(   190 )      ! XLO2+RO2=0.6500D+00*XOPN+...
     &                      +    2.4400D-01 * RXRAT(   245 )      ! CL+XYLMN=0.2440D+00*XOPN+...
     &                      +    2.4400D-01 * RXRAT(   246 )      ! CL+NAPH=0.2440D+00*XOPN+...
      LOSS(  XOPN         ) =                 RXRAT(   198 )      ! XOPN=0.4000D+00*GLY+XO2H+...
     &                      +                 RXRAT(   199 )      ! XOPN+OH=MGLY+0.4000D+...
     &                      +                 RXRAT(   200 )      ! XOPN+O3=0.1200D+01*MGLY+...
     &                      +                 RXRAT(   201 )      ! XOPN+NO3=0.5000D+00*NO2+...

      PROD(  XYLMN        ) =   0.0D0
      LOSS(  XYLMN        ) =                 RXRAT(   185 )      ! XYLMN+OH=0.1550D+00*CRES+...
     &                      +                 RXRAT(   245 )      ! XYLMN+CL=HCL+0.1550D+...

      PROD(  XLO2         ) =    5.4400D-01 * RXRAT(   185 )      ! XYLMN+OH=0.5440D+00*XLO2+...
     &                      +    5.4400D-01 * RXRAT(   186 )      ! NAPH+OH=0.5440D+00*XLO2+...
     &                      +    5.4400D-01 * RXRAT(   245 )      ! CL+XYLMN=0.5440D+00*XLO2+...
     &                      +    5.4400D-01 * RXRAT(   246 )      ! CL+NAPH=0.5440D+00*XLO2+...
      LOSS(  XLO2         ) =                 RXRAT(   187 )      ! XLO2+NO=0.8600D+00*NO2+...
     &                      +                 RXRAT(   188 )      ! XLO2+HO2=
     &                      +                 RXRAT(   189 )      ! XLO2+C2O3=0.2600D+00*GLY+...
     &                      +                 RXRAT(   190 )      ! XLO2+RO2=0.2600D+00*GLY+...

      PROD(  XYLRO2       ) =                 RXRAT(   185 )      ! XYLMN+OH=XYLRO2+0.5440D+...
     &                      +                 RXRAT(   245 )      ! CL+XYLMN=XYLRO2+0.1550D+...
      LOSS(  XYLRO2       ) =                 RXRAT(   254 )      ! XYLRO2+NO=NO+XYLNRXN
     &                      +                 RXRAT(   255 )      ! XYLRO2+HO2=HO2+XYLHRXN

      PROD(  NAPH         ) =   0.0D0
      LOSS(  NAPH         ) =                 RXRAT(   186 )      ! NAPH+OH=0.1550D+00*CRES+...
     &                      +                 RXRAT(   246 )      ! NAPH+CL=HCL+0.1550D+...

      PROD(  PAHRO2       ) =                 RXRAT(   186 )      ! NAPH+OH=PAHRO2+0.5440D+...
     &                      +                 RXRAT(   246 )      ! CL+NAPH=PAHRO2+0.1550D+...
      LOSS(  PAHRO2       ) =                 RXRAT(   261 )      ! PAHRO2+NO=NO+PAHNRXN
     &                      +                 RXRAT(   262 )      ! PAHRO2+HO2=HO2+PAHHRXN

      PROD(  CRO          ) =    2.0000D-01 * RXRAT(   191 )      ! CRES+OH=0.2000D+00*CRO+...
     &                      +    3.0000D-01 * RXRAT(   192 )      ! CRES+NO3=0.3000D+00*CRO+...
     &                      +    5.0000D-01 * RXRAT(   195 )      ! CRON+OH=0.5000D+00*CRO+NTR2
     &                      +    5.0000D-01 * RXRAT(   196 )      ! CRON+NO3=0.5000D+00*CRO+...
     &                      +    5.0000D-01 * RXRAT(   206 )      ! CAT1+OH=0.5000D+00*CRO+...
     &                      +                 RXRAT(   207 )      ! CAT1+NO3=CRO+HNO3
      LOSS(  CRO          ) =                 RXRAT(   193 )      ! CRO+NO2=CRON
     &                      +                 RXRAT(   194 )      ! CRO+HO2=CRES

      PROD(  CAT1         ) =    7.3200D-01 * RXRAT(   191 )      ! CRES+OH=0.7320D+00*CAT1+...
      LOSS(  CAT1         ) =                 RXRAT(   206 )      ! CAT1+OH=0.1400D+00*FORM+...
     &                      +                 RXRAT(   207 )      ! CAT1+NO3=CRO+HNO3

      PROD(  CRON         ) =                 RXRAT(   193 )      ! CRO+NO2=CRON
      LOSS(  CRON         ) =                 RXRAT(   195 )      ! CRON+OH=NTR2+0.5000D+00*CRO
     &                      +                 RXRAT(   196 )      ! CRON+NO3=NTR2+0.5000D+...
     &                      +                 RXRAT(   197 )      ! CRON=HONO+HO2+FORM+OPEN

      PROD(  OPAN         ) =                 RXRAT(   209 )      ! OPO3+NO2=OPAN
      LOSS(  OPAN         ) =                 RXRAT(   210 )      ! OPAN=OPO3+NO2
     &                      +                 RXRAT(   214 )      ! OPAN+OH=0.5000D+00*NO2+...

      PROD(  ECH4         ) =   0.0D0
      LOSS(  ECH4         ) =                 RXRAT(   216 )      ! ECH4+OH=MEO2+RO2

      PROD(  CL2          ) =    3.0000D-01 * RXRAT(   224 )      ! CLO+CLO=0.3000D+00*CL2+...
      LOSS(  CL2          ) =                 RXRAT(   221 )      ! CL2=0.2000D+01*CL

      PROD(  CL           ) =    2.0000D+00 * RXRAT(   221 )      ! CL2=0.2000D+01*CL
     &                      +                 RXRAT(   222 )      ! HOCL=CL+OH
     &                      +    1.4000D+00 * RXRAT(   224 )      ! CLO+CLO=0.1400D+01*CL+...
     &                      +                 RXRAT(   225 )      ! CLO+NO=CL+NO2
     &                      +                 RXRAT(   227 )      ! CLO+MEO2=CL+FORM+HO2
     &                      +                 RXRAT(   228 )      ! OH+FMCL=CL+CO
     &                      +                 RXRAT(   229 )      ! FMCL=CL+CO+HO2
     &                      +                 RXRAT(   243 )      ! HCL+OH=CL
     &                      +                 RXRAT(   247 )      ! CLNO2=CL+NO2
     &                      +                 RXRAT(   250 )      ! CLNO3=CL+NO3
      LOSS(  CL           ) =                 RXRAT(   223 )      ! CL+O3=CLO
     &                      +                 RXRAT(   230 )      ! CL=HCL+MEO2+RO2
     &                      +                 RXRAT(   231 )      ! CL+PAR=HCL+XPAR
     &                      +                 RXRAT(   232 )      ! CL+PRPA=HCL+ACET+0.9700D+...
     &                      +                 RXRAT(   233 )      ! CL+ETHA=HCL+0.9910D+...
     &                      +                 RXRAT(   234 )      ! CL+ETH=FMCL+0.2000D+01*XO2+...
     &                      +                 RXRAT(   235 )      ! CL+OLE=FMCL+0.3300D+...
     &                      +                 RXRAT(   236 )      ! CL+IOLE=0.3000D+00*HCL+...
     &                      +                 RXRAT(   237 )      ! CL+ISOP=FMCL+ISPD+0.9600D+...
     &                      +                 RXRAT(   238 )      ! CL+FORM=HCL+HO2+CO
     &                      +                 RXRAT(   239 )      ! CL+ALD2=HCL+C2O3
     &                      +                 RXRAT(   240 )      ! CL+ALDX=HCL+CXO3
     &                      +                 RXRAT(   241 )      ! CL+MEOH=HCL+HO2+FORM
     &                      +                 RXRAT(   242 )      ! CL+ETOH=HCL+HO2+ALD2
     &                      +                 RXRAT(   244 )      ! CL+TOL=HCL+0.1800D+00*CRES+...
     &                      +                 RXRAT(   245 )      ! CL+XYLMN=HCL+0.1550D+...
     &                      +                 RXRAT(   246 )      ! CL+NAPH=HCL+0.1550D+...

      PROD(  HOCL         ) =                 RXRAT(   226 )      ! CLO+HO2=HOCL
     &                      +                 RXRAT(   251 )      ! CLNO3=HOCL+HNO3
      LOSS(  HOCL         ) =                 RXRAT(   222 )      ! HOCL=OH+CL

      PROD(  CLO          ) =                 RXRAT(   223 )      ! CL+O3=CLO
     &                      +                 RXRAT(   249 )      ! CLNO3=CLO+NO2
      LOSS(  CLO          ) =    2.0000D+00 * RXRAT(   224 )      ! CLO+CLO=0.3000D+00*CL2+...
     &                      +                 RXRAT(   225 )      ! CLO+NO=CL+NO2
     &                      +                 RXRAT(   226 )      ! CLO+HO2=HOCL
     &                      +                 RXRAT(   227 )      ! CLO+MEO2=CL+FORM+HO2
     &                      +                 RXRAT(   248 )      ! CLO+NO2=CLNO3

      PROD(  FMCL         ) =                 RXRAT(   234 )      ! CL+ETH=FMCL+0.2000D+01*XO2+...
     &                      +                 RXRAT(   235 )      ! CL+OLE=FMCL+0.3300D+...
     &                      +    7.0000D-01 * RXRAT(   236 )      ! CL+IOLE=0.7000D+00*FMCL+...
     &                      +                 RXRAT(   237 )      ! CL+ISOP=FMCL+ISPD+0.9600D+...
      LOSS(  FMCL         ) =                 RXRAT(   228 )      ! FMCL+OH=CL+CO
     &                      +                 RXRAT(   229 )      ! FMCL=CL+CO+HO2

      PROD(  HCL          ) =                 RXRAT(   230 )      ! CL=HCL+MEO2+RO2
     &                      +                 RXRAT(   231 )      ! CL+PAR=HCL+XPAR
     &                      +                 RXRAT(   232 )      ! CL+PRPA=HCL+ACET+0.9700D+...
     &                      +                 RXRAT(   233 )      ! CL+ETHA=HCL+0.9910D+...
     &                      +    3.0000D-01 * RXRAT(   236 )      ! CL+IOLE=0.3000D+00*HCL+...
     &                      +                 RXRAT(   238 )      ! CL+FORM=HCL+HO2+CO
     &                      +                 RXRAT(   239 )      ! CL+ALD2=HCL+C2O3
     &                      +                 RXRAT(   240 )      ! CL+ALDX=HCL+CXO3
     &                      +                 RXRAT(   241 )      ! CL+MEOH=HCL+HO2+FORM
     &                      +                 RXRAT(   242 )      ! CL+ETOH=HCL+HO2+ALD2
     &                      +                 RXRAT(   244 )      ! CL+TOL=HCL+0.1800D+00*CRES+...
     &                      +                 RXRAT(   245 )      ! CL+XYLMN=HCL+0.1550D+...
     &                      +                 RXRAT(   246 )      ! CL+NAPH=HCL+0.1550D+...
      LOSS(  HCL          ) =                 RXRAT(   243 )      ! HCL+OH=CL

      PROD(  CLNO2        ) =                 RXRAT(   269 )      ! H2NO3PIJ+ACLI=CLNO2
     &                      +                 RXRAT(   270 )      ! H2NO3PIJ+ACLJ=CLNO2
     &                      +                 RXRAT(   271 )      ! H2NO3PK+ACLK=CLNO2
      LOSS(  CLNO2        ) =                 RXRAT(   247 )      ! CLNO2=CL+NO2

      PROD(  CLNO3        ) =                 RXRAT(   248 )      ! CLO+NO2=CLNO3
      LOSS(  CLNO3        ) =                 RXRAT(   249 )      ! CLNO3=CLO+NO2
     &                      +                 RXRAT(   250 )      ! CLNO3=CL+NO3
     &                      +                 RXRAT(   251 )      ! CLNO3=HOCL+HNO3

      PROD(  TOLNRXN      ) =                 RXRAT(   252 )      ! TOLRO2+NO=TOLNRXN+NO
      LOSS(  TOLNRXN      ) =   0.0D0

      PROD(  TOLHRXN      ) =                 RXRAT(   253 )      ! TOLRO2+HO2=TOLHRXN+HO2
      LOSS(  TOLHRXN      ) =   0.0D0

      PROD(  XYLNRXN      ) =                 RXRAT(   254 )      ! XYLRO2+NO=XYLNRXN+NO
      LOSS(  XYLNRXN      ) =   0.0D0

      PROD(  XYLHRXN      ) =                 RXRAT(   255 )      ! XYLRO2+HO2=XYLHRXN+HO2
      LOSS(  XYLHRXN      ) =   0.0D0

      PROD(  BNZNRXN      ) =                 RXRAT(   256 )      ! BENZRO2+NO=BNZNRXN+NO
      LOSS(  BNZNRXN      ) =   0.0D0

      PROD(  BNZHRXN      ) =                 RXRAT(   257 )      ! BENZRO2+HO2=BNZHRXN+HO2
      LOSS(  BNZHRXN      ) =   0.0D0

      PROD(  SESQ         ) =   0.0D0
      LOSS(  SESQ         ) =                 RXRAT(   258 )      ! SESQ+O3=O3+SESQRXN
     &                      +                 RXRAT(   259 )      ! SESQ+OH=OH+SESQRXN
     &                      +                 RXRAT(   260 )      ! SESQ+NO3=NO3+SESQRXN

      PROD(  SESQRXN      ) =                 RXRAT(   258 )      ! SESQ+O3=SESQRXN+O3
     &                      +                 RXRAT(   259 )      ! SESQ+OH=SESQRXN+OH
     &                      +                 RXRAT(   260 )      ! SESQ+NO3=SESQRXN+NO3
      LOSS(  SESQRXN      ) =   0.0D0

      PROD(  PAHNRXN      ) =                 RXRAT(   261 )      ! PAHRO2+NO=PAHNRXN+NO
      LOSS(  PAHNRXN      ) =   0.0D0

      PROD(  PAHHRXN      ) =                 RXRAT(   262 )      ! PAHRO2+HO2=PAHHRXN+HO2
      LOSS(  PAHHRXN      ) =   0.0D0

      PROD(  SOAALK       ) =   0.0D0
      LOSS(  SOAALK       ) =                 RXRAT(   263 )      ! SOAALK+OH=OH+0.4700D+00*ALKRXN

      PROD(  ALKRXN       ) =    4.7000D-01 * RXRAT(   263 )      ! SOAALK+OH=0.4700D+00*ALKRXN+OH
      LOSS(  ALKRXN       ) =   0.0D0

      PROD(  H2NO3PIJ     ) =                 RXRAT(   265 )      ! N2O5=H2NO3PIJ+HNO3
      LOSS(  H2NO3PIJ     ) =                 RXRAT(   267 )      ! H2NO3PIJ=HNO3
     &                      +                 RXRAT(   269 )      ! H2NO3PIJ+ACLI=CLNO2
     &                      +                 RXRAT(   270 )      ! H2NO3PIJ+ACLJ=CLNO2

      PROD(  H2NO3PK      ) =                 RXRAT(   266 )      ! N2O5=H2NO3PK+HNO3
      LOSS(  H2NO3PK      ) =                 RXRAT(   268 )      ! H2NO3PK=HNO3
     &                      +                 RXRAT(   271 )      ! H2NO3PK+ACLK=CLNO2

      PROD(  ACLI         ) =   0.0D0
      LOSS(  ACLI         ) =                 RXRAT(   269 )      ! ACLI+H2NO3PIJ=CLNO2

      PROD(  ACLJ         ) =   0.0D0
      LOSS(  ACLJ         ) =                 RXRAT(   270 )      ! ACLJ+H2NO3PIJ=CLNO2

      PROD(  ACLK         ) =   0.0D0
      LOSS(  ACLK         ) =                 RXRAT(   271 )      ! ACLK+H2NO3PK=CLNO2

      PROD(  AISO3J       ) =                 RXRAT(   274 )      ! EPOX=AISO3J
      LOSS(  AISO3J       ) =   0.0D0

      PROD(  AGLYJ        ) =                 RXRAT(   275 )      ! GLY=AGLYJ
     &                      +                 RXRAT(   276 )      ! MGLY=AGLYJ
      LOSS(  AGLYJ        ) =   0.0D0

      PROD(  AXYL1J       ) =   0.0D0
      LOSS(  AXYL1J       ) =                 RXRAT(   277 )      ! AXYL1J=0.8571D+00*AOLGAJ

      PROD(  AOLGAJ       ) =    8.5710D-01 * RXRAT(   277 )      ! AXYL1J=0.8571D+00*AOLGAJ
     &                      +    1.1429D+00 * RXRAT(   278 )      ! AXYL2J=0.1143D+01*AOLGAJ
     &                      +    8.5710D-01 * RXRAT(   279 )      ! ATOL1J=0.8571D+00*AOLGAJ
     &                      +    1.1429D+00 * RXRAT(   280 )      ! ATOL2J=0.1143D+01*AOLGAJ
     &                      +    7.1430D-01 * RXRAT(   281 )      ! ABNZ1J=0.7143D+00*AOLGAJ
     &                      +    7.1430D-01 * RXRAT(   282 )      ! ABNZ2J=0.7143D+00*AOLGAJ
     &                      +    1.4286D+00 * RXRAT(   288 )      ! APAH1J=0.1429D+01*AOLGAJ
     &                      +    1.4286D+00 * RXRAT(   289 )      ! APAH2J=0.1429D+01*AOLGAJ
     &                      +    1.7143D+00 * RXRAT(   290 )      ! AALK1J=0.1714D+01*AOLGAJ
     &                      +    1.7143D+00 * RXRAT(   291 )      ! AALK2J=0.1714D+01*AOLGAJ
      LOSS(  AOLGAJ       ) =   0.0D0

      PROD(  AXYL2J       ) =   0.0D0
      LOSS(  AXYL2J       ) =                 RXRAT(   278 )      ! AXYL2J=0.1143D+01*AOLGAJ

      PROD(  ATOL1J       ) =   0.0D0
      LOSS(  ATOL1J       ) =                 RXRAT(   279 )      ! ATOL1J=0.8571D+00*AOLGAJ

      PROD(  ATOL2J       ) =   0.0D0
      LOSS(  ATOL2J       ) =                 RXRAT(   280 )      ! ATOL2J=0.1143D+01*AOLGAJ

      PROD(  ABNZ1J       ) =   0.0D0
      LOSS(  ABNZ1J       ) =                 RXRAT(   281 )      ! ABNZ1J=0.7143D+00*AOLGAJ

      PROD(  ABNZ2J       ) =   0.0D0
      LOSS(  ABNZ2J       ) =                 RXRAT(   282 )      ! ABNZ2J=0.7143D+00*AOLGAJ

      PROD(  ATRP1J       ) =   0.0D0
      LOSS(  ATRP1J       ) =                 RXRAT(   283 )      ! ATRP1J=0.8000D+00*AOLGBJ

      PROD(  AOLGBJ       ) =    8.0000D-01 * RXRAT(   283 )      ! ATRP1J=0.8000D+00*AOLGBJ
     &                      +    9.0000D-01 * RXRAT(   284 )      ! ATRP2J=0.9000D+00*AOLGBJ
     &                      +    5.0000D-01 * RXRAT(   285 )      ! AISO1J=0.5000D+00*AOLGBJ
     &                      +    5.0000D-01 * RXRAT(   286 )      ! AISO2J=0.5000D+00*AOLGBJ
     &                      +    1.5000D+00 * RXRAT(   287 )      ! ASQTJ=0.1500D+01*AOLGBJ
      LOSS(  AOLGBJ       ) =   0.0D0

      PROD(  ATRP2J       ) =   0.0D0
      LOSS(  ATRP2J       ) =                 RXRAT(   284 )      ! ATRP2J=0.9000D+00*AOLGBJ

      PROD(  AISO1J       ) =   0.0D0
      LOSS(  AISO1J       ) =                 RXRAT(   285 )      ! AISO1J=0.5000D+00*AOLGBJ

      PROD(  AISO2J       ) =   0.0D0
      LOSS(  AISO2J       ) =                 RXRAT(   286 )      ! AISO2J=0.5000D+00*AOLGBJ

      PROD(  ASQTJ        ) =   0.0D0
      LOSS(  ASQTJ        ) =                 RXRAT(   287 )      ! ASQTJ=0.1500D+01*AOLGBJ

      PROD(  APAH1J       ) =   0.0D0
      LOSS(  APAH1J       ) =                 RXRAT(   288 )      ! APAH1J=0.1429D+01*AOLGAJ

      PROD(  APAH2J       ) =   0.0D0
      LOSS(  APAH2J       ) =                 RXRAT(   289 )      ! APAH2J=0.1429D+01*AOLGAJ

      PROD(  AALK1J       ) =   0.0D0
      LOSS(  AALK1J       ) =                 RXRAT(   290 )      ! AALK1J=0.1714D+01*AOLGAJ

      PROD(  AALK2J       ) =   0.0D0
      LOSS(  AALK2J       ) =                 RXRAT(   291 )      ! AALK2J=0.1714D+01*AOLGAJ

      PROD(  APOCI        ) =   0.0D0
      LOSS(  APOCI        ) =   0.0D0

      PROD(  APNCOMI      ) =    1.2500D+00 * RXRAT(   292 )      ! APOCI+OH=0.1250D+...
      LOSS(  APNCOMI      ) =                 RXRAT(   293 )      ! APNCOMI+OH=OH

      PROD(  APOCJ        ) =   0.0D0
      LOSS(  APOCJ        ) =   0.0D0

      PROD(  APNCOMJ      ) =    1.2500D+00 * RXRAT(   294 )      ! APOCJ+OH=0.1250D+...
      LOSS(  APNCOMJ      ) =                 RXRAT(   295 )      ! APNCOMJ+OH=OH

      PROD(  PCVOC        ) =   0.0D0
      LOSS(  PCVOC        ) =                 RXRAT(   296 )      ! PCVOC+OH=OH+PCSOARXN

      PROD(  PCSOARXN     ) =                 RXRAT(   296 )      ! PCVOC+OH=PCSOARXN+OH
      LOSS(  PCSOARXN     ) =   0.0D0

      PROD(  VLVPO1       ) =    3.0030D-01 * RXRAT(   298 )      ! VSVPO1+OH=0.3003D+...
     &                      +    3.8560D-01 * RXRAT(   299 )      ! VSVPO2+OH=0.3856D+...
     &                      +    2.1810D-01 * RXRAT(   300 )      ! VSVPO3+OH=0.2181D+...
     &                      +    2.4120D-01 * RXRAT(   301 )      ! VIVPO1+OH=0.2412D+...
      LOSS(  VLVPO1       ) =    5.1430D-01 * RXRAT(   297 )      ! VLVPO1+OH=0.4857D+...

      PROD(  VSVPO1       ) =    6.2000D-03 * RXRAT(   297 )      ! VLVPO1+OH=0.6200D-...
     &                      +    9.5000D-02 * RXRAT(   299 )      ! VSVPO2+OH=0.9500D-...
     &                      +    3.0630D-01 * RXRAT(   300 )      ! VSVPO3+OH=0.3063D+...
     &                      +    2.0890D-01 * RXRAT(   301 )      ! VIVPO1+OH=0.2089D+...
      LOSS(  VSVPO1       ) =    7.1380D-01 * RXRAT(   298 )      ! VSVPO1+OH=0.2862D+...

      PROD(  VSVPO2       ) =    2.5000D-03 * RXRAT(   297 )      ! VLVPO1+OH=0.2500D-...
     &                      +    4.1000D-03 * RXRAT(   298 )      ! VSVPO1+OH=0.4100D-...
     &                      +    1.5300D-02 * RXRAT(   300 )      ! VSVPO3+OH=0.1530D-...
     &                      +    3.0000D-01 * RXRAT(   301 )      ! VIVPO1+OH=0.3000D+...
      LOSS(  VSVPO2       ) =    8.6270D-01 * RXRAT(   299 )      ! VSVPO2+OH=0.1373D+...

      PROD(  VSVPO3       ) =    2.6000D-03 * RXRAT(   297 )      ! VLVPO1+OH=0.2600D-...
     &                      +    3.5000D-03 * RXRAT(   298 )      ! VSVPO1+OH=0.3500D-...
     &                      +    5.0000D-04 * RXRAT(   299 )      ! VSVPO2+OH=0.5000D-...
      LOSS(  VSVPO3       ) =    8.9570D-01 * RXRAT(   300 )      ! VSVPO3+OH=0.1043D+...

      PROD(  VIVPO1       ) =    2.3000D-03 * RXRAT(   297 )      ! VLVPO1+OH=0.2300D-...
      LOSS(  VIVPO1       ) =                 RXRAT(   301 )      ! VIVPO1+OH=OH+0.2412D+...

      PROD(  VLVOO1       ) =    2.9440D-01 * RXRAT(   297 )      ! VLVPO1+OH=0.2944D+...
     &                      +    2.2390D-01 * RXRAT(   298 )      ! VSVPO1+OH=0.2239D+...
     &                      +    2.0510D-01 * RXRAT(   299 )      ! VSVPO2+OH=0.2051D+...
     &                      +    1.8930D-01 * RXRAT(   300 )      ! VSVPO3+OH=0.1893D+...
     &                      +    2.0280D-01 * RXRAT(   301 )      ! VIVPO1+OH=0.2028D+...
     &                      +    2.8580D-01 * RXRAT(   303 )      ! VLVOO2+OH=0.2858D+...
     &                      +    3.3030D-01 * RXRAT(   304 )      ! VSVOO1+OH=0.3303D+...
     &                      +    3.4440D-01 * RXRAT(   305 )      ! VSVOO2+OH=0.3444D+...
     &                      +    3.8860D-01 * RXRAT(   306 )      ! VSVOO3+OH=0.3886D+...
      LOSS(  VLVOO1       ) =    3.3360D-01 * RXRAT(   302 )      ! VLVOO1+OH=0.6664D+...

      PROD(  VLVOO2       ) =    2.0210D-01 * RXRAT(   297 )      ! VLVPO1+OH=0.2021D+...
     &                      +    1.8200D-01 * RXRAT(   298 )      ! VSVPO1+OH=0.1820D+...
     &                      +    1.7640D-01 * RXRAT(   299 )      ! VSVPO2+OH=0.1764D+...
     &                      +    1.6680D-01 * RXRAT(   300 )      ! VSVPO3+OH=0.1668D+...
     &                      +    4.7100D-02 * RXRAT(   301 )      ! VIVPO1+OH=0.4710D-...
     &                      +    1.4300D-02 * RXRAT(   302 )      ! VLVOO1+OH=0.1430D-...
     &                      +    2.2720D-01 * RXRAT(   304 )      ! VSVOO1+OH=0.2272D+...
     &                      +    2.7490D-01 * RXRAT(   305 )      ! VSVOO2+OH=0.2749D+...
     &                      +    2.4210D-01 * RXRAT(   306 )      ! VSVOO3+OH=0.2421D+...
      LOSS(  VLVOO2       ) =    6.0690D-01 * RXRAT(   303 )      ! VLVOO2+OH=0.3931D+...

      PROD(  VSVOO2       ) =    1.9000D-03 * RXRAT(   297 )      ! VLVPO1+OH=0.1900D-...
     &                      +    1.2390D-01 * RXRAT(   302 )      ! VLVOO1+OH=0.1239D+...
     &                      +    1.0270D-01 * RXRAT(   303 )      ! VLVOO2+OH=0.1027D+...
     &                      +    7.0200D-02 * RXRAT(   304 )      ! VSVOO1+OH=0.7020D-...
     &                      +    3.8500D-02 * RXRAT(   306 )      ! VSVOO3+OH=0.3850D-...
      LOSS(  VSVOO2       ) =    7.4230D-01 * RXRAT(   305 )      ! VSVOO2+OH=0.2577D+...

      PROD(  VSVOO3       ) =    2.3000D-03 * RXRAT(   297 )      ! VLVPO1+OH=0.2300D-...
     &                      +    1.8310D-01 * RXRAT(   302 )      ! VLVOO1+OH=0.1831D+...
     &                      +    2.0450D-01 * RXRAT(   303 )      ! VLVOO2+OH=0.2045D+...
     &                      +    1.1160D-01 * RXRAT(   304 )      ! VSVOO1+OH=0.1116D+...
     &                      +    7.3900D-02 * RXRAT(   305 )      ! VSVOO2+OH=0.7390D-...
      LOSS(  VSVOO3       ) =    7.3330D-01 * RXRAT(   306 )      ! VSVOO3+OH=0.2667D+...

      PROD(  VSVOO1       ) =    1.2300D-02 * RXRAT(   302 )      ! VLVOO1+OH=0.1230D-...
     &                      +    1.3900D-02 * RXRAT(   303 )      ! VLVOO2+OH=0.1390D-...
     &                      +    4.9100D-02 * RXRAT(   305 )      ! VSVOO2+OH=0.4910D-...
     &                      +    6.4000D-02 * RXRAT(   306 )      ! VSVOO3+OH=0.6400D-...
      LOSS(  VSVOO1       ) =    7.3930D-01 * RXRAT(   304 )      ! VSVOO1+OH=0.2607D+...

      PROD(  FORM_PRIMARY ) =   0.0D0
      LOSS(  FORM_PRIMARY ) =                 RXRAT(   307 )      ! FORM_PRIMARY+OH=OH
     &                      +                 RXRAT(   308 )      ! FORM_PRIMARY+NO3=NO3
     &                      +                 RXRAT(   309 )      ! FORM_PRIMARY+O=O
     &                      +                 RXRAT(   310 )      ! FORM_PRIMARY=
     &                      +                 RXRAT(   311 )      ! FORM_PRIMARY=
     &                      +                 RXRAT(   312 )      ! FORM_PRIMARY+CL=CL

      PROD(  ALD2_PRIMARY ) =   0.0D0
      LOSS(  ALD2_PRIMARY ) =                 RXRAT(   313 )      ! ALD2_PRIMARY+OH=OH
     &                      +                 RXRAT(   314 )      ! ALD2_PRIMARY+NO3=NO3
     &                      +                 RXRAT(   315 )      ! ALD2_PRIMARY+O=O
     &                      +                 RXRAT(   316 )      ! ALD2_PRIMARY=
     &                      +                 RXRAT(   317 )      ! ALD2_PRIMARY+CL=CL

      PROD(  BUTADIENE13  ) =   0.0D0
      LOSS(  BUTADIENE13  ) =                 RXRAT(   318 )      ! BUTADIENE13+OH=OH+0.5800D+...
     &                      +                 RXRAT(   319 )      ! BUTADIENE13+O3=O3+0.5200D+...
     &                      +                 RXRAT(   320 )      ! BUTADIENE13+NO3=NO3+...
     &                      +                 RXRAT(   321 )      ! BUTADIENE13+CL=CL+0.5800D+...

      PROD(  ACROLEIN     ) =    5.8000D-01 * RXRAT(   318 )      ! BUTADIENE13+OH=0.5800D+...
     &                      +    5.2000D-01 * RXRAT(   319 )      ! BUTADIENE13+O3=0.5200D+...
     &                      +    4.5000D-02 * RXRAT(   320 )      ! BUTADIENE13+NO3=0.4500D-...
     &                      +    5.8000D-01 * RXRAT(   321 )      ! BUTADIENE13+CL=0.5800D+...
      LOSS(  ACROLEIN     ) =                 RXRAT(   327 )      ! ACROLEIN+OH=OH
     &                      +                 RXRAT(   328 )      ! ACROLEIN+O3=O3
     &                      +                 RXRAT(   329 )      ! ACROLEIN+NO3=NO3
     &                      +                 RXRAT(   330 )      ! ACROLEIN=
     &                      +                 RXRAT(   331 )      ! ACROLEIN+CL=CL

      PROD(  ACRO_PRIMARY ) =   0.0D0
      LOSS(  ACRO_PRIMARY ) =                 RXRAT(   322 )      ! ACRO_PRIMARY+OH=OH
     &                      +                 RXRAT(   323 )      ! ACRO_PRIMARY+O3=O3
     &                      +                 RXRAT(   324 )      ! ACRO_PRIMARY+NO3=NO3
     &                      +                 RXRAT(   325 )      ! ACRO_PRIMARY=
     &                      +                 RXRAT(   326 )      ! ACRO_PRIMARY+CL=CL

      PROD(  TOLU         ) =   0.0D0
      LOSS(  TOLU         ) =                 RXRAT(   332 )      ! TOLU+OH=OH
     &                      +                 RXRAT(   333 )      ! TOLU+CL=CL

      PROD(  HG           ) =   0.0D0
      LOSS(  HG           ) =                 RXRAT(   334 )      ! HG+O3=0.5000D+00*HGIIAER+...
     &                      +                 RXRAT(   335 )      ! HG+CL2=HGIIGAS+CL2
     &                      +                 RXRAT(   336 )      ! HG+H2O2=HGIIGAS+H2O2
     &                      +                 RXRAT(   337 )      ! HG+OH=0.5000D+00*HGIIAER+...
     &                      +    5.0000D-01 * RXRAT(   338 )      ! HG+CL=0.5000D+00*HG+...

      PROD(  HGIIAER      ) =    5.0000D-01 * RXRAT(   334 )      ! HG+O3=0.5000D+00*HGIIAER+...
     &                      +    5.0000D-01 * RXRAT(   337 )      ! HG+OH=0.5000D+00*HGIIAER+...
      LOSS(  HGIIAER      ) =   0.0D0

      PROD(  HGIIGAS      ) =    5.0000D-01 * RXRAT(   334 )      ! HG+O3=0.5000D+00*HGIIGAS+...
     &                      +                 RXRAT(   335 )      ! HG+CL2=HGIIGAS+CL2
     &                      +                 RXRAT(   336 )      ! HG+H2O2=HGIIGAS+H2O2
     &                      +    5.0000D-01 * RXRAT(   337 )      ! HG+OH=0.5000D+00*HGIIGAS+...
     &                      +    5.0000D-01 * RXRAT(   338 )      ! HG+CL=0.5000D+00*HGIIGAS+...
      LOSS(  HGIIGAS      ) =   0.0D0

      PNEG( PAR ) =    2.5000D+00 * RXRAT(   128 )      ! KET=-0.2500D+01*PAR+...
     &            +    2.7000D+00 * RXRAT(   133 )      ! ROR=-0.2700D+01*PAR+...
     &            +    7.3000D-01 * RXRAT(   142 )      ! OLE+OH=-0.7300D+00*PAR+...
     &            +    7.9000D-01 * RXRAT(   143 )      ! OLE+O3=-0.7900D+00*PAR+...
     &            +                 RXRAT(   144 )      ! OLE+NO3=-PAR+0.5000D+...
     &            +    1.2600D-01 * RXRAT(   220 )      ! XPAR=-0.1260D+00*PAR+...
     &            +                 RXRAT(   235 )      ! CL+OLE=-PAR+0.3300D+...

      RETURN

      END
